@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *    $Id: blockmean.c,v 1.42 2006/05/14 01:43:04 pwessel Exp $
+ *    $Id: blockmean.c,v 1.44 2006/05/27 06:29:38 pwessel Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -65,7 +65,7 @@ struct BLK_SLH {
 
 int main (int argc, char **argv)
 {
-	BOOLEAN	error = FALSE, nofile = TRUE, done = FALSE, first = TRUE;
+	BOOLEAN	error = FALSE, nofile = TRUE, done = FALSE, first = TRUE, use_xy;
 
 	FILE *fp = NULL;
 
@@ -109,7 +109,7 @@ int main (int argc, char **argv)
 				/* Supplemental parameters */
                               
 				case 'C':	/* Report center of block instead */
-					Ctrl->C.active = FALSE;
+					Ctrl->C.active = TRUE;
 					break;
 				case 'E':	/* Extended report with standard deviation, min, and max in cols 4-6 */
 					Ctrl->E.active = TRUE;
@@ -236,19 +236,27 @@ int main (int argc, char **argv)
 	n_blocks = ((size_t)h.nx) * ((size_t)h.ny);
 	
 	if ((zw = (struct BLK_PAIR *) GMT_memory (VNULL, n_blocks, sizeof (struct BLK_PAIR), GMT_program)) == NULL) {
-		fprintf (stderr, "%s: ERROR: Unable to allocate memory for %u blocks [%d bytes for zw].\n", GMT_program, n_blocks, (int)sizeof (struct BLK_PAIR));
+		fprintf (stderr, "%s: ERROR: Unable to allocate memory for ", GMT_program);
+		PRINT_SIZE_T (stderr, n_blocks);
+		fprintf (stderr, " blocks [%d bytes for zw].\n", (int)sizeof (struct BLK_PAIR));
 		exit (EXIT_FAILURE);
 	}
-	if (Ctrl->C.active && (xy = (struct BLK_PAIR *) GMT_memory (VNULL, n_blocks, sizeof (struct BLK_PAIR), GMT_program)) == NULL) {
-		fprintf (stderr, "%s: ERROR: Unable to allocate memory for %u blocks [%d bytes for xy].\n", GMT_program, n_blocks, (int)sizeof (struct BLK_PAIR));
+	if (!Ctrl->C.active && (xy = (struct BLK_PAIR *) GMT_memory (VNULL, n_blocks, sizeof (struct BLK_PAIR), GMT_program)) == NULL) {
+		fprintf (stderr, "%s: ERROR: Unable to allocate memory for ", GMT_program);
+		PRINT_SIZE_T (stderr, n_blocks);
+		fprintf (stderr, " blocks [%d bytes for xy].\n", (int)sizeof (struct BLK_PAIR));
 		exit (EXIT_FAILURE);
 	}
 	if (Ctrl->E.active && (slh = (struct BLK_SLH *) GMT_memory (VNULL, n_blocks, sizeof (struct BLK_SLH), GMT_program)) == NULL) {
-		fprintf (stderr, "%s: ERROR: Unable to allocate memory for %u blocks [%d bytes for slh].\n", GMT_program, n_blocks, (int)sizeof (struct BLK_SLH));
+		fprintf (stderr, "%s: ERROR: Unable to allocate memory for ", GMT_program);
+		PRINT_SIZE_T (stderr, n_blocks);
+		fprintf (stderr, " blocks [%d bytes for slh].\n", (int)sizeof (struct BLK_SLH));
 		exit (EXIT_FAILURE);
 	}
 	if ((Ctrl->W.weighted[GMT_IN] && Ctrl->E.active) && (np = (int *) GMT_memory (VNULL, n_blocks, sizeof (int), GMT_program)) == NULL) {
-		fprintf (stderr, "%s: ERROR: Unable to allocate memory for %u blocks [%d bytes for counter].\n", GMT_program, n_blocks, (int)sizeof (int));
+		fprintf (stderr, "%s: ERROR: Unable to allocate memory for ", GMT_program);
+		PRINT_SIZE_T (stderr, n_blocks);
+		fprintf (stderr, " blocks [%d bytes for counter].\n", (int)sizeof (int));
 		exit (EXIT_FAILURE);
 	}
 	if (gmtdefs.verbose) {
@@ -257,7 +265,7 @@ int main (int argc, char **argv)
 		sprintf (format, "%%s: W: %s E: %s S: %s N: %s nx: %%d ny: %%d\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
 		fprintf (stderr, format, GMT_program, h.x_min, h.x_max, h.y_min, h.y_max, h.nx, h.ny);
 		mem = (double)sizeof (struct BLK_PAIR);
-		if (Ctrl->C.active) mem += (double)sizeof (struct BLK_PAIR);
+		if (!Ctrl->C.active) mem += (double)sizeof (struct BLK_PAIR);
 		if (Ctrl->E.active) mem += (double)sizeof (struct BLK_SLH);
 		if (Ctrl->W.weighted[GMT_IN] && Ctrl->E.active) mem += (double)sizeof (int);
 		mem *= (double)n_blocks;
@@ -269,6 +277,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: Using a total of %.3g %cb for all arrays.\n", GMT_program, mem, unit);
 	}
 
+	use_xy = !Ctrl->C.active;	/* If not -C then we must keep track of x,y locations */
 	GMT_set_xy_domain (wesn, &h);	/* May include some padding if gridline-registered */
 
 	n_read = n_pitched = 0;
@@ -311,7 +320,9 @@ int main (int argc, char **argv)
 		while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
 			if (GMT_io.status & GMT_IO_MISMATCH) {
-				fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %u\n", GMT_program, n_fields,  n_expected_fields, n_read);
+				fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line ", GMT_program, n_fields,  n_expected_fields);
+				PRINT_SIZE_T (stderr, n_read);
+				fprintf (stderr, "\n");
 				exit (EXIT_FAILURE);
 			}
 
@@ -334,7 +345,7 @@ int main (int argc, char **argv)
 			weight = (Ctrl->W.weighted[GMT_IN]) ? in[3] : 1.0;
 			weighted_z = in[2] * weight;
 			ij = ((size_t)j) * ((size_t)h.nx) + ((size_t)i);		/* 64-bit safe 1-D index */
-			if (Ctrl->C.active) {
+			if (use_xy) {
 				xy[ij].a[BLK_X] += (in[0]*weight);
 				xy[ij].a[BLK_Y] += (in[1]*weight);
 			}
@@ -369,7 +380,7 @@ int main (int argc, char **argv)
 		n_cells_filled++;
 		if (Ctrl->W.weighted[GMT_OUT]) out[w_col] = zw[ij].a[BLK_W];
 		iw = 1.0 / zw[ij].a[BLK_W];
-		if (Ctrl->C.active) {
+		if (use_xy) {
 			out[0] = xy[ij].a[BLK_X] * iw;
 			out[1] = xy[ij].a[BLK_Y] * iw;
 		}
@@ -400,7 +411,7 @@ int main (int argc, char **argv)
 	}
 
 	GMT_free ((void *)zw);
-	if (Ctrl->C.active) GMT_free ((void *)xy);
+	if (use_xy) GMT_free ((void *)xy);
 	if (Ctrl->E.active) {
 		GMT_free ((void *)slh);
 		if (Ctrl->W.weighted[GMT_IN]) GMT_free ((void *)np);
@@ -408,8 +419,11 @@ int main (int argc, char **argv)
 	
 	n_lost = n_read - n_pitched;
 	if (gmtdefs.verbose) {
-		fprintf (stderr, "%s: N read: %u\tN used: %u\tN outside: %u\tN cells filled: %u\n",
-		GMT_program, n_read, n_pitched, n_lost, n_cells_filled);
+		fprintf(stderr,"%s: N read: ", GMT_program);	PRINT_SIZE_T (stderr, n_read);
+		fprintf(stderr," N used: ");	PRINT_SIZE_T (stderr, n_pitched);
+		fprintf(stderr," N outside_area: ");	PRINT_SIZE_T (stderr, n_lost);
+		fprintf(stderr," N cells filled: ");	PRINT_SIZE_T (stderr, n_cells_filled);
+		fprintf(stderr,"\n");
 	}
 
         GMT_end (argc, argv);
