@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *    $Id: blockmedian.c,v 1.35 2006/05/14 01:43:04 pwessel Exp $
+ *    $Id: blockmedian.c,v 1.37 2006/05/27 06:29:38 pwessel Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -93,7 +93,7 @@ int main (int argc, char **argv)
 				/* Supplemental parameters */
                               
 				case 'C':
-					Ctrl->C.active = FALSE;
+					Ctrl->C.active = TRUE;
 					break;
 				case 'E':
 					Ctrl->E.active = TRUE;		/* Extended report with standard deviation, min, and max in cols 4-6 */
@@ -175,7 +175,7 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
-	if (!Ctrl->C.active && go_quickly == 1) {
+	if (Ctrl->C.active && go_quickly == 1) {
 		fprintf (stderr, "%s: GMT WARNING:  -C overrides -Q\n", GMT_program);
 		go_quickly = 0;
 	}
@@ -222,7 +222,7 @@ int main (int argc, char **argv)
 	GMT_RI_prepare (&h);	/* Ensure -R -I consistency and set nx, ny */
 
 	go_quickly = (Ctrl->Q.active) ? 1 : 0;	
-	if (!Ctrl->C.active) go_quickly = 2;	/* Flag used in output calculation */
+	if (Ctrl->C.active) go_quickly = 2;	/* Flag used in output calculation */
 	h.xy_off = 0.5 * h.node_offset;	/* Use to calculate mean location of block */
 
 	if (gmtdefs.verbose) {
@@ -275,7 +275,9 @@ int main (int argc, char **argv)
 		while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
 			if (GMT_io.status & GMT_IO_MISMATCH) {
-				fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %u\n", GMT_program, n_fields,  n_expected_fields, n_read);
+				fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line ", GMT_program, n_fields,  n_expected_fields);
+				PRINT_SIZE_T (stderr, n_read);
+				fprintf (stderr, "\n");
 				exit (EXIT_FAILURE);
 			}
 
@@ -295,7 +297,7 @@ int main (int argc, char **argv)
 
 			data[n_pitched].i = index;
 			data[n_pitched].a[BLK_W] = ((Ctrl->W.weighted[GMT_IN]) ? in[3] : 1.0);
-			if (Ctrl->C.active) {
+			if (!Ctrl->C.active) {
 				data[n_pitched].a[BLK_X] = in[0];
 				data[n_pitched].a[BLK_Y] = in[1];
 			}
@@ -314,7 +316,12 @@ int main (int argc, char **argv)
 	data = (struct BLK_DATA *) GMT_memory ((void *)data, n_pitched, sizeof (struct BLK_DATA), GMT_program);
 	
 	n_lost = n_read - n_pitched;
-	if (gmtdefs.verbose) fprintf(stderr,"%s: N read: %u N used: %u N outside_area: %u\n", GMT_program, n_read, n_pitched, n_lost);
+	if (gmtdefs.verbose) {
+		fprintf(stderr,"%s: N read: ", GMT_program);	PRINT_SIZE_T (stderr, n_read);
+		fprintf(stderr," N used: ");	PRINT_SIZE_T (stderr, n_pitched);
+		fprintf(stderr," N outside_area: ");	PRINT_SIZE_T (stderr, n_lost);
+		fprintf(stderr,"\n");
+	}
 
 	/* Ready to go. */
 
@@ -371,7 +378,11 @@ int main (int argc, char **argv)
 		first_in_cell = first_in_new_cell;
 	}
 
-	if (gmtdefs.verbose) fprintf(stderr,"%s: N_cells_filled: %u\n", GMT_program, n_cells_filled);
+	if (gmtdefs.verbose) {
+		fprintf(stderr,"%s: N_cells_filled: ", GMT_program);
+		PRINT_SIZE_T (stderr, n_cells_filled);
+		fprintf(stderr,"\n");
+	}
 
 	GMT_free ((void *)data);
 	if (Ctrl->E.active) GMT_free ((void *)z_tmp);
