@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *    $Id: blockmode.c,v 1.36 2006/05/14 01:43:04 pwessel Exp $
+ *    $Id: blockmode.c,v 1.38 2006/10/27 23:45:22 pwessel Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -30,7 +30,7 @@
    Modified:	3.3.5: 10-JUL-2000 PW: Added -L option
    Version:	3.4 01-MAR-2001 by PW, Replace -N with -F, and added -C
    Version:	4 01-MAR-2003 by PW
-   Version:	4.1: 14-SEP-2005 by PW, Added enhanced -I
+   Version:	4.1.x: 14-SEP-2005 by PW, Added enhanced -I
    		4-APR-2006 by PW: Added -E for LMS scale, low, and high value
 			Also implemented size_t counters to be 64-bit compatible.
 */
@@ -260,7 +260,9 @@ int main (int argc, char **argv)
 		while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 
 			if (GMT_io.status & GMT_IO_MISMATCH) {
-				fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %u\n", GMT_program, n_fields,  n_expected_fields, n_read);
+				fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line ", GMT_program, n_fields,  n_expected_fields);
+				PRINT_SIZE_T (stderr, n_read);
+				fprintf (stderr, "\n");
 				exit (EXIT_FAILURE);
 			}
 
@@ -298,7 +300,12 @@ int main (int argc, char **argv)
 
 	data = (struct BLK_DATA *) GMT_memory ((void *)data, n_pitched, sizeof(struct BLK_DATA), GMT_program);
 	n_lost = n_read - n_pitched;
-	if (gmtdefs.verbose) fprintf(stderr,"%s: N read: %u N used: %u N outside_area: %u\n", GMT_program, n_read, n_pitched, n_lost);
+	if (gmtdefs.verbose) {
+		fprintf(stderr,"%s: N read: ", GMT_program);	PRINT_SIZE_T (stderr, n_read);
+		fprintf(stderr," N used: ");	PRINT_SIZE_T (stderr, n_pitched);
+		fprintf(stderr," N outside_area: ");	PRINT_SIZE_T (stderr, n_lost);
+		fprintf(stderr,"\n");
+	}
 
 	/* Ready to go. */
 
@@ -418,7 +425,11 @@ int main (int argc, char **argv)
 		first_in_cell = first_in_new_cell;
 	}
 
-	if (gmtdefs.verbose) fprintf(stderr,"%s: N_cells_filled: %u\n", GMT_program, n_cells_filled);
+	if (gmtdefs.verbose) {
+		fprintf(stderr,"%s: N_cells_filled: ", GMT_program);
+		PRINT_SIZE_T (stderr, n_cells_filled);
+		fprintf(stderr,"\n");
+	}
 
 	GMT_free ((void *)data);
 	if (Ctrl->E.active) GMT_free ((void *)z_tmp);
