@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt.h,v 1.130 2006/04/12 13:55:18 remko Exp $
+ *	$Id: gmt.h,v 1.136 2006/10/29 07:18:54 pwessel Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -59,6 +59,7 @@
 #include <math.h>
 #include <limits.h>
 #include <stddef.h>
+#include <sys/stat.h>
 #ifdef __MACHTEN__
 /* Kludge to fix a Machten POSIX bug */
 #include <sys/types.h>
@@ -201,6 +202,21 @@
 	(((data) << 24) | (((data) << 8) & 0x00ff0000) | \
 	(((data) >> 8) & 0x0000ff00) | ((unsigned int)(data) >> 24))
 
+/* Macro for printing the value of size_t */
+
+#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
+/*
+ * This is a C99 compiler, so it supports %zu; no need to cast.
+ */
+#define PRINT_SIZE_T(fp,u) fprintf(fp, "%zu", u)
+#else
+/*
+ * This is not a C99 compiler; assume size_t is no bigger than
+ * unsigned long.
+ */
+#define PRINT_SIZE_T(fp,u) fprintf(fp, "%lu", (unsigned long)u)
+#endif
+
 /*--------------------------------------------------------------------
  *			GMT TYPEDEF DEFINITIONS
  *--------------------------------------------------------------------*/
@@ -220,7 +236,7 @@ typedef double GMT_dtime;	/* GMT internal time representation */
 #define GMT_HASH_SIZE 122		/* Used in get_gmtdefaults, should be ~> GMT_N_KEYS */
 /* This structure contains default parameters for the GMT system */
 
-#define GMT_N_ELLIPSOIDS	63
+#define GMT_N_ELLIPSOIDS	64
 #define GMT_N_DATUMS	223
 
 #define GMT_PEN_LEN	128
@@ -249,7 +265,7 @@ struct GMT_DEFAULTS {
 	int nan_rgb[3];			/* Color of NaNs [0/0/0] */
 	int color_image;		/* 0 = Adobe's colorimage, 1 = Tiles, 2 = RGB-separation */
 	int color_model;		/* 1 = read RGB, 2 = use RGB, 4 = read HSV, 8 = use HSV, 16 = read CMYK, 32 = use CMYK [1+2] */
-	char d_format[GMT_TEXT_LEN];	/* Default double output format [%lg] */
+	char d_format[GMT_TEXT_LEN];	/* Default double output format [%g] */
 	int degree_format;		/* 0 = <0/360/-90/90>, 1 = <-180/180/-90/90>, 2 = <0/180/0/90>
 					   3 = 0E/180E/180W/0W/90S/90N> */
 	int dpi;			/* Dots pr. inch plotter resolution [300] */
@@ -354,8 +370,8 @@ struct GMT_PS {	/* Holds the current settings that affect PS generation */
 	BOOLEAN verbose;			/* TRUE to give verbose feedback from pslib routines [FALSE] */
 	BOOLEAN heximage;			/* TRUE to write images in HEX, FALSE in BIN [TRUE] */
 	BOOLEAN absolute;			/* TRUE if -X, -Y was absolute [FALSE] */
-	BOOLEAN last_page;			/* Result of -K [was gmtdefs.last_page] */
-	BOOLEAN overlay;			/* Result of -O [was gmtdefs.overlay] */
+	BOOLEAN last_page;			/* Result of not -K [TRUE] */
+	BOOLEAN overlay;			/* Result of -O [FALSE] */
 	BOOLEAN unix_time;			/* Result of -U [gmtdefs.unix_time] */
 	BOOLEAN comments;			/* TRUE to write comments to PS file [FALSE] */
 	BOOLEAN clip_on;			/* TRUE if clipping will extend beyond current process */
@@ -467,6 +483,8 @@ EXTERN_MSC struct GMT_DEFAULTS gmtdefs;
 
 EXTERN_MSC int GMT_N_FONTS;				/* Number of fonts loaded from share/pslib */
 EXTERN_MSC char *GMTHOME;			/* Points to the GMT home directory with lib subdir */
+EXTERN_MSC char *GMT_HOMEDIR;			/* Points to the GMT user home directory [~] */
+EXTERN_MSC char *GMT_USERDIR;			/* Points to the GMT user .gmt directory [~/.gmt] */
 EXTERN_MSC char *GMT_CPTDIR;			/* Points to the GMT cpt directory [if set] */
 EXTERN_MSC char *GMT_DATADIR;			/* Points to the GMT misc directory [if set] */
 EXTERN_MSC char *GMT_GRIDDIR;			/* Points to the GMT grids directory [if set] */
