@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_boundcond.h,v 1.3.4.5 2004/01/02 22:23:10 pwessel Exp $
+ *	$Id: gmt_boundcond.h,v 1.8 2006/10/27 23:45:23 pwessel Exp $
  *
- *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
  *
  * Author:	W H F Smith
  * Date:	17 April 1998
- * Version:	3.4.3
+ * Version:	4.1.x
  *
  */
 
