@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_globals.h,v 1.7 2006/04/10 04:43:31 pwessel Exp $
+ *	$Id: gmt_globals.h,v 1.10 2006/10/17 20:26:46 remko Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -98,7 +98,8 @@ double GMT_dlat = 0.0;				/* Steps taken in latitude along gridlines (gets reset
 
 struct GMT_LUT *GMT_lut;		/* CPT lookup table read by GMT_read_cpt */
 struct GMT_BFN_COLOR GMT_bfn[3];	/* Structures with back/fore/nan colors */
-int GMT_n_colors = 0;
+int GMT_n_colors = 0;			/* Number of colors in CPT lookup table */
+int GMT_cpt_flags = 0;			/* Flags controling use of BFN colors */
 BOOLEAN GMT_gray;			/* TRUE if only grayshades are needed */
 BOOLEAN GMT_b_and_w;			/* TRUE if only black and white are needed */
 BOOLEAN GMT_continuous;			/* TRUE if continuous color tables have been given */
@@ -184,6 +185,8 @@ int GMT_inc_code[2] = {0, 0};
 
 
 char *GMTHOME = CNULL;
+char *GMT_HOMEDIR = CNULL;
+char *GMT_USERDIR = CNULL;
 char *GMT_CPTDIR = CNULL;
 char *GMT_DATADIR = CNULL;
 char *GMT_GRIDDIR = CNULL;
@@ -206,7 +209,6 @@ int GMT_no_rgb[3] = {-1, -1, -1};
 
 int GMT_oldargc;
 char *GMT_oldargv[GMT_N_UNIQUE];	/* Pointers to old common arguments */
-BOOLEAN GMT_processed_option[GMT_N_UNIQUE];	/* TRUE if option has been procssed */
 BOOLEAN GMT_give_synopsis_and_exit = FALSE;
 
 struct GMT_TIME_LANGUAGE GMT_time_language;	/* For time axis */
