@@ -1,4 +1,4 @@
-/*	$Id: gmt_mgg_header2.c,v 1.4 2004/09/28 19:24:13 pwessel Exp $
+/*	$Id: gmt_mgg_header2.c,v 1.13 2006/10/23 03:35:57 pwessel Exp $
  *
  *	Code donated by David Divens, NOAA/NGDC
  *	This is the README file:
@@ -6,7 +6,7 @@
  Adding MGG file format to GMT
 -----------------------------
 1) Modify gmt_grdio.h
-   - Increment N_GRD_FORMATS.
+   - Increment GMT_N_GRD_FORMATS.
      This number is one based, the formats are zero based so this
      value will be one greater than the grid number you are creating.
      
@@ -95,9 +95,9 @@ static void GMT2MGG2(struct GRD_HEADER *gmt, MGG_GRID_HEADER_2 *mgg)
 	mgg->maxValue    = (int)rint(gmt->z_max * mgg->precision);
 
 	/* Data fits in two byte boundry */
-	if ((-32767 <= mgg->minValue) && (mgg->maxValue <= 32767)) {
+	if ((-SHRT_MAX <= mgg->minValue) && (mgg->maxValue <= SHRT_MAX)) {
 		mgg->numType = sizeof(short);
-		mgg->nanValue = (short)-32768;
+		mgg->nanValue = (short)SHRT_MIN;
 	}
 #ifdef BYTE_SIZE
 	/* Data fits in one byte boundry */
@@ -192,15 +192,16 @@ static void swap_header(MGG_GRID_HEADER_2 *header)
    swap_long(&header->unused11);
 }
 
-int mgg2_read_grd_info(char *file, struct GRD_HEADER *header)
-{
-	FILE			*fp = NULL;
-	MGG_GRID_HEADER_2	mggHeader;
+int GMT_is_mgg2_grid (char *file)
+{	/* Determine if file is a Sun rasterfile */
+	FILE *fp = NULL;
+	MGG_GRID_HEADER_2 mggHeader;
 
-	if (!strcmp(file, "=")) {
-		fp = stdin;
-/*	} else if ((fp = fopen(file, "rb")) == NULL) { */
-	} else if ((fp = GMT_fopen(file, GMT_io.r_mode)) == NULL) {
+	if (!strcmp(file, "=")) {	/* Cannot check on pipes */
+		fprintf (stderr, "GMT Fatal Error: Cannot guess grid format type if grid is passed via pipe!\n");
+		exit (EXIT_FAILURE);
+	}
+	if ((fp = GMT_fopen(file, GMT_io.r_mode)) == NULL) {
 		fprintf(stderr, "GMT Fatal Error: Could not open file %s!\n", file);
 		exit (-1);
 	}
@@ -211,6 +212,32 @@ int mgg2_read_grd_info(char *file, struct GRD_HEADER *header)
 		exit (-1);
 	}
 
+	/* Swap header bytes if necessary */
+	swap_header(&mggHeader);
+
+	/* Check the magic number and size of header */
+	if (mggHeader.version < MGG_MAGIC_NUM + VERSION) return (-1);	/* Not this kind of file */
+	return (GMT_grd_format_decoder ("rf"));
+}
+
+int mgg2_read_grd_info (struct GRD_HEADER *header)
+{
+	FILE			*fp = NULL;
+	MGG_GRID_HEADER_2	mggHeader;
+
+	if (!strcmp(header->name, "=")) {
+		fp = stdin;
+	} else if ((fp = GMT_fopen(header->name, GMT_io.r_mode)) == NULL) {
+		fprintf(stderr, "GMT Fatal Error: Could not open file %s!\n", header->name);
+		exit (-1);
+	}
+
+	memset(&mggHeader, '\0', sizeof(MGG_GRID_HEADER_2));
+	if (fread(&mggHeader, sizeof(MGG_GRID_HEADER_2), 1, fp) != 1) {
+		fprintf(stderr, "GMT Fatal Error: Error reading file %s!\n", header->name);
+		exit (-1);
+	}
+
     /* Swap header bytes if necessary */
     swap_header(&mggHeader);
 
@@ -221,7 +248,7 @@ int mgg2_read_grd_info(char *file, struct GRD_HEADER *header)
 	}
 
 	if (mggHeader.length != sizeof(MGG_GRID_HEADER_2)) {
-		fprintf(stderr, "GMT Fatal Error: Invalid grid header size, expected %d, found %d\n", sizeof(MGG_GRID_HEADER_2), mggHeader.length);
+		fprintf(stderr, "GMT Fatal Error: Invalid grid header size, expected %d, found %d\n", (int)sizeof(MGG_GRID_HEADER_2), mggHeader.length);
 		exit (-1);
 	}
 
@@ -232,16 +259,15 @@ int mgg2_read_grd_info(char *file, struct GRD_HEADER *header)
 	return FALSE;
 }
 
-int mgg2_write_grd_info(char *file, struct GRD_HEADER *header)
+int mgg2_write_grd_info (struct GRD_HEADER *header)
 {
 	FILE			*fp;
 	MGG_GRID_HEADER_2	mggHeader;
 	
-	if (!strcmp(file, "=")) {
+	if (!strcmp(header->name, "=")) {
 		fp = stdout;
-/*	} else if ((fp = fopen(file, "wb")) == NULL) {       */
-	} else if ((fp = GMT_fopen(file, GMT_io.w_mode)) == NULL) {
-		fprintf(stderr, "GMT Fatal Error: Could not create file %s!\n", file);
+	} else if ((fp = GMT_fopen(header->name, GMT_io.w_mode)) == NULL) {
+		fprintf(stderr, "GMT Fatal Error: Could not create file %s!\n", header->name);
 		exit (-1);
 	}
 	
@@ -251,7 +277,7 @@ int mgg2_write_grd_info(char *file, struct GRD_HEADER *header)
     swap_header(&mggHeader);
 
 	if (fwrite (&mggHeader, sizeof(MGG_GRID_HEADER_2), 1, fp) != 1) {
-		fprintf (stderr, "GMT Fatal Error: Error writing file %s!\n", file);
+		fprintf (stderr, "GMT Fatal Error: Error writing file %s!\n", header->name);
 		exit (-1);
 	}
 
@@ -260,16 +286,7 @@ int mgg2_write_grd_info(char *file, struct GRD_HEADER *header)
 	return FALSE;
 }
 
-int mgg2_read_grd (
-	char *file,
-	struct GRD_HEADER *header,
-	float *grid,
-	double w, 
-	double e, 
-	double s, 
-	double n,
-	int pad[],
-	BOOLEAN complex)
+int mgg2_read_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, int pad[], BOOLEAN complex)
 {
 	MGG_GRID_HEADER_2	mggHeader;
 	FILE  *fp     = NULL;
@@ -279,27 +296,27 @@ int mgg2_read_grd (
 	int first_col, last_col, first_row, last_row, nm, kk, one_or_zero;
 	int i, j, j2, ij, width_in, width_out, height_in, i_0_out, inc = 1;
 	BOOLEAN piping = FALSE, geo = FALSE;
-	double off, half_or_zero, x, small;
+	double half_or_zero, x, small;
 	long long_offset;	/* For fseek only */
 	
 	if (complex) {
-		fprintf (stderr, "GMT Fatal Error: MGG grdfile %s cannot hold complex data!\n", file);
+		fprintf (stderr, "GMT Fatal Error: MGG grdfile %s cannot hold complex data!\n", header->name);
 		exit (-1);
 	}
 
-	if (!strcmp (file, "=")) {
+	if (!strcmp (header->name, "=")) {
 		fp = stdin;
 		piping = TRUE;
 	}
-/*	else if ((fp = fopen (file, "rb")) != NULL) {  */
-	else if ((fp = GMT_fopen (file, GMT_io.r_mode)) != NULL) {
+/*	else if ((fp = fopen (header->name, "rb")) != NULL) {  */
+	else if ((fp = GMT_fopen (header->name, GMT_io.r_mode)) != NULL) {
 		fread(&mggHeader, 1, sizeof(MGG_GRID_HEADER_2), fp);
         swap_header(&mggHeader);
 		if (mggHeader.numType == 0) mggHeader.numType = sizeof(int);
 	}
 
 	else {
-		fprintf (stderr, "GMT Fatal Error: Could not open file %s! (%s)", file);
+		fprintf (stderr, "GMT Fatal Error: Could not open file! (%s)", header->name);
 		exit (-1);
 	}
 	
@@ -309,8 +326,8 @@ int mgg2_read_grd (
 		tShort = (short *) tLong;
 		tChar  = (char *) tLong;
 
-		if (fread ((char *)tLong, mggHeader.numType, nm, fp) != (size_t)nm) {
-			fprintf (stderr, "GMT Fatal Error: Error reading file %s! (%s)", file);
+		if (fread ((void *)tLong, mggHeader.numType, nm, fp) != (size_t)nm) {
+			fprintf (stderr, "GMT Fatal Error: Error reading file! (%s)", header->name);
 			exit (-1);
 		}
 		for (i = 0; i < nm; i++) {
@@ -340,7 +357,7 @@ int mgg2_read_grd (
 				exit(-1);
 			}
 		}
-		GMT_free ((char *)tLong);
+		GMT_free ((void *)tLong);
 		fclose(fp);
 		return (FALSE);
 	}
@@ -350,7 +367,6 @@ int mgg2_read_grd (
 	if (w < header->x_min || e > header->x_max) geo = TRUE;	/* Dealing with periodic grid */
 	
 	one_or_zero = (header->node_offset) ? 0 : 1;
-	off = (header->node_offset) ? 0.0 : 0.5;
 	
 	/* Get dimension of subregion */
 	
@@ -393,12 +409,12 @@ int mgg2_read_grd (
 				x += 360.0;
 			else if ((x - header->x_max) > small)
 				x -= 360.0;
-			k[i] = (int) floor (((x - header->x_min) / header->x_inc) + off);
+			k[i] = GMT_x_to_i (x, header->x_min, header->x_inc, half_or_zero, header->nx);
 		}
 		if (piping)	{ /* Skip data by reading it */
 			for (j = 0; j < first_row; j++) {
-				if (fread ((char *) tLong, mggHeader.numType, header->nx, fp) != (size_t)header->nx) {
-					fprintf (stderr, "GMT Fatal Error: Error reading file %s!\n", file);
+				if (fread ((void *) tLong, mggHeader.numType, header->nx, fp) != (size_t)header->nx) {
+					fprintf (stderr, "GMT Fatal Error: Error reading file %s!\n", header->name);
 					exit (-1);
 				}
 			}
@@ -408,8 +424,8 @@ int mgg2_read_grd (
 		}
 		
 		for (j = first_row, j2 = 0; j <= last_row; j++, j2++) {
-			if (fread ((char *) tLong, mggHeader.numType, header->nx, fp) != (size_t)header->nx) {
-				fprintf (stderr, "GMT Fatal Error: Error reading file %s!\n", file);
+			if (fread ((void *) tLong, mggHeader.numType, header->nx, fp) != (size_t)header->nx) {
+				fprintf (stderr, "GMT Fatal Error: Error reading file %s!\n", header->name);
 				exit (-1);
 			}
 			
@@ -441,14 +457,14 @@ int mgg2_read_grd (
 		}
 		if (piping)	{ /* Skip data by reading it */
 			for (j = last_row + 1; j < header->ny; j++) {
-				if (fread ((char *) tLong, mggHeader.numType, header->nx, fp) != (size_t)header->nx) {
-					fprintf (stderr, "GMT Fatal Error: Error reading file %s!\n", file);
+				if (fread ((void *) tLong, mggHeader.numType, header->nx, fp) != (size_t)header->nx) {
+					fprintf (stderr, "GMT Fatal Error: Error reading file %s!\n", header->name);
 					exit (-1);
 				}
 			}
 		}
 			
-		GMT_free ((char *)k);
+		GMT_free ((void *)k);
 	}
 	else {	/* A bit easier here */
 		tLong = (int *) GMT_memory (CNULL, header->nx, sizeof (int), "mgg_read_grd");
@@ -457,8 +473,8 @@ int mgg2_read_grd (
 
 		if (piping)	{ /* Skip data by reading it */
 			for (j = 0; j < first_row; j++) {
-				if (fread ((char *) tLong, mggHeader.numType, header->nx, fp) != (size_t)header->nx) {
-					fprintf (stderr, "GMT Fatal Error: Error reading file %s!\n", file);
+				if (fread ((void *) tLong, mggHeader.numType, header->nx, fp) != (size_t)header->nx) {
+					fprintf (stderr, "GMT Fatal Error: Error reading file %s!\n", header->name);
 					exit (-1);
 				}
 			}
@@ -469,8 +485,8 @@ int mgg2_read_grd (
 		
 		for (j = first_row, j2 = 0; j <= last_row; j++, j2++) {
 			ij = (j2 + pad[3]) * width_out + i_0_out;
-			if (fread ((char *) tLong, mggHeader.numType, header->nx, fp) != (size_t)header->nx) {
-				fprintf (stderr, "GMT Fatal Error: Error reading file %s!\n", file);
+			if (fread ((void *) tLong, mggHeader.numType, header->nx, fp) != (size_t)header->nx) {
+				fprintf (stderr, "GMT Fatal Error: Error reading file %s!\n", header->name);
 				exit (-1);
 			}
 			
@@ -505,8 +521,8 @@ int mgg2_read_grd (
 
 		if (piping)	{/* Skip data by reading it */
 			for (j = last_row + 1; j < header->ny; j++) {
-				if (fread ((char *) tLong, mggHeader.numType, header->nx, fp)) {
-					fprintf (stderr, "GMT Fatal Error: Error reading file %s!\n", file);
+				if (fread ((void *) tLong, mggHeader.numType, header->nx, fp)) {
+					fprintf (stderr, "GMT Fatal Error: Error reading file %s!\n", header->name);
 					exit (-1);
 				}
 			}
@@ -531,21 +547,12 @@ int mgg2_read_grd (
 	}
 	if (fp != stdin) fclose (fp);
 	
-	GMT_free ((char *)tLong);
+	GMT_free ((void *)tLong);
 	return (FALSE);
 }
 
 	
-int mgg2_write_grd(
-	char *file, 
-	struct GRD_HEADER *header, 
-	float *grid,
-	double w, 
-	double e, 
-	double s, 
-	double n, 
-	int *pad, 
-	BOOLEAN complex)
+int mgg2_write_grd (struct GRD_HEADER *header, float *grid, double w, double e, double s, double n, int *pad, BOOLEAN complex)
 {
 	MGG_GRID_HEADER_2	mggHeader;
 	int i, i2, nm, kk, *k;
@@ -553,7 +560,7 @@ int mgg2_write_grd(
 	int first_col, last_col, first_row, last_row;
 	
 	BOOLEAN geo = FALSE;
-	double off, half_or_zero, small, x;
+	double half_or_zero, small, x;
 	
 	int  *tLong;
 	short *tShort;
@@ -561,15 +568,15 @@ int mgg2_write_grd(
 	FILE *fp;
 	
 	if (complex) {
-		fprintf (stderr, "GMT Fatal Error: MGG grdfile %s cannot hold complex data!\n", file);
+		fprintf (stderr, "GMT Fatal Error: MGG grdfile %s cannot hold complex data!\n", header->name);
 		exit (-1);
 	}
-	if (!strcmp (file, "=")) {
+	if (!strcmp (header->name, "=")) {
 		fp = stdout;
 	}
-/*	else if ((fp = fopen (file, "wb")) == NULL) {      */
-	else if ((fp = GMT_fopen (file, GMT_io.w_mode)) == NULL) {
-		fprintf (stderr, "GMT Fatal Error: Could not create file %s!\n", file);
+/*	else if ((fp = fopen (header->name, "wb")) == NULL) {      */
+	else if ((fp = GMT_fopen (header->name, GMT_io.w_mode)) == NULL) {
+		fprintf (stderr, "GMT Fatal Error: Could not create file %s!\n", header->name);
 		exit (-1);
 	}
 	
@@ -587,7 +594,7 @@ int mgg2_write_grd(
 		GMT2MGG2(header, &mggHeader);
 		swap_header(&mggHeader);
 		if (fwrite (&mggHeader, sizeof (MGG_GRID_HEADER_2), 1, fp) != 1) {
-			fprintf (stderr, "GMT Fatal Error: Error writing file %s!\n", file);
+			fprintf (stderr, "GMT Fatal Error: Error writing file %s!\n", header->name);
 			exit (-1);
 		}
 		swap_header(&mggHeader);
@@ -634,17 +641,16 @@ int mgg2_write_grd(
 			}
 		}
 		if (fwrite (tLong, mggHeader.numType, nm, fp) != (size_t)nm) {
-			fprintf (stderr, "GMT Fatal Error: Error writing file %s!\n", file);
+			fprintf (stderr, "GMT Fatal Error: Error writing file %s!\n", header->name);
 			exit (-1);
 		}
-		GMT_free ((char *)tLong);
+		GMT_free ((void *)tLong);
 		return (FALSE);
 	}
 
 	if (w < header->x_min || e > header->x_max) geo = TRUE;	/* Dealing with periodic grid */
 	
 	one_or_zero = (header->node_offset) ? 0 : 1;
-	off = (header->node_offset) ? 0.0 : 0.5;
 	
 	/* Get dimension of subregion to write */
 	
@@ -690,7 +696,7 @@ int mgg2_write_grd(
 	GMT2MGG2(header, &mggHeader);
 	swap_header(&mggHeader);
 	if (fwrite (&mggHeader, sizeof (MGG_GRID_HEADER_2), 1, fp) != 1) {
-		fprintf (stderr, "GMT Fatal Error: Error writing file %s!\n", file);
+		fprintf (stderr, "GMT Fatal Error: Error writing file %s!\n", header->name);
 		exit (-1);
 	}
 	swap_header(&mggHeader);
@@ -710,7 +716,7 @@ int mgg2_write_grd(
 				x += 360.0;
 			else if ((x - header->x_max) > small)
 				x -= 360.0;
-			k[i] = (int) floor (((x - header->x_min) / header->x_inc) + off);
+			k[i] = GMT_x_to_i (x, header->x_min, header->x_inc, half_or_zero, header->nx);
 		}
 		i2 = first_col + pad[0];
 		for (j = 0, j2 = first_row + pad[3]; j < height_out; j++, j2++) {
@@ -748,9 +754,9 @@ int mgg2_write_grd(
 				if (mggHeader.numType == sizeof(int)) swap_long(&tLong[i]);
 				else if (mggHeader.numType == sizeof(short)) swap_word(&tShort[i]);
 			}
-			fwrite ((char *)tLong, mggHeader.numType, width_out, fp);
+			fwrite ((void *)tLong, mggHeader.numType, width_out, fp);
 		}
-		GMT_free ((char *)k);
+		GMT_free ((void *)k);
 	}
 	else {
 		i2 = first_col + pad[0];
@@ -788,12 +794,12 @@ int mgg2_write_grd(
 				if (mggHeader.numType == sizeof(int)) swap_long(&tLong[i]);
 				else if (mggHeader.numType == sizeof(short)) swap_word(&tShort[i]);
 			}
-			fwrite ((char *)tLong, mggHeader.numType, width_out, fp);
+			fwrite ((void *)tLong, mggHeader.numType, width_out, fp);
 		}
 	}
 	if (fp != stdout) fclose (fp);
 	
-	GMT_free ((char *)tLong);
+	GMT_free ((void *)tLong);
 	
 	return (FALSE);
 }
