@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_shore.h,v 1.3.4.5 2004/01/02 22:23:11 pwessel Exp $
+ *	$Id: gmt_shore.h,v 1.13 2006/10/27 23:45:23 pwessel Exp $
  *
- *	Copyright (c) 1991-2004 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,16 +25,16 @@
  * Author:	Paul Wessel
  * Date:	12-AUG-1995
  * Revised:	15-AUG-1998
- * Version:	3.4.3
+ * Version:	4.1.x
  */
 
 #include "netcdf.h"
 
-#define MAX_DELTA 65535	/* Largest value to store in a unsigned short, used as largest dx or dy in bin  */
-#define MAX_LEVEL	4	/* Highest hierarchical level of coastlines */
+#define GSHHS_MAX_DELTA 65535	/* Largest value to store in a unsigned short, used as largest dx or dy in bin  */
+#define GMT_MAX_GSHHS_LEVEL	4	/* Highest hierarchical level of coastlines */
 
-#define N_BLEVELS	3	/* Number of levels for borders */
-#define N_RLEVELS	10	/* Number of levels for rivers */
+#define GMT_N_BLEVELS		3	/* Number of levels for borders */
+#define GMT_N_RLEVELS		10	/* Number of levels for rivers */
 
 struct GMT_SHORE {
 
@@ -49,7 +49,7 @@ struct GMT_SHORE {
 	int ns;			/* Number of segments to use in current bin */
 	unsigned char node_level[4];
 	struct GMT_SHORE_SEGMENT *seg;	/* Array of these segments */
-	struct SIDE *side[4];		/* Has position & id for each side exit/entry */
+	struct GSHHS_SIDE *side[4];		/* Has position & id for each side exit/entry */
 	int nside[4];			/* Number of entries per side, including corner */
 	int n_entries;
 	BOOLEAN leftmost_bin;		/* TRUE if current bin is at left edge of map */
@@ -76,7 +76,7 @@ struct GMT_SHORE {
 	char title[80];		/* Title of data set */
 	char source[80];	/* Source of data set */
 
-	/* Netcdf ID variables */
+	/* netCDF ID variables */
 	
 	int cdfid;		/* File id for coastbin file */
 	
@@ -108,7 +108,7 @@ struct GMT_SHORE_SEGMENT {
 	short *dy;		/* Array of scaled latitudes relative to SW corner */
 };
 
-struct SIDE {
+struct GSHHS_SIDE {
 	unsigned short pos;	/* Position along side in 0-65535 range */
 	short id;	/* Local segment id */
 };
@@ -145,7 +145,7 @@ struct GMT_BR {	/* Structure for Borders and Rivers */
 	char title[80];		/* Title of data set */
 	char source[80];	/* Source of data set */
 
-	/* Netcdf ID variables */
+	/* netCDF ID variables */
 	
 	int cdfid;		/* File id for coastbin file */
 	
@@ -169,12 +169,12 @@ struct GMT_BR {	/* Structure for Borders and Rivers */
 
 struct GMT_BR_SEGMENT {
 	unsigned short n;	/* Number of points in segment */
-	unsigned short level;	/* Hierarchial level of segment */
+	unsigned short level;	/* Hierarchical level of segment */
 	short *dx;		/* Array of scaled longitudes relative to SW corner */
 	short *dy;		/* Array of scaled latitudes relative to SW corner */
 };
 
-struct POL {
+struct GMT_GSHHS_POL {
 	int n;
 	int interior;	/* TRUE if polygon is inside bin */
 	int level;
@@ -186,16 +186,16 @@ struct POL {
 
 EXTERN_MSC void GMT_get_shore_bin (int b, struct GMT_SHORE *c, double min_area, int min_level, int max_level);
 EXTERN_MSC void GMT_get_br_bin (int b, struct GMT_BR *c, int *level, int n_levels);
-EXTERN_MSC void GMT_free_polygons (struct POL *p, int n);
+EXTERN_MSC void GMT_free_polygons (struct GMT_GSHHS_POL *p, int n);
 EXTERN_MSC void GMT_free_shore (struct GMT_SHORE *c);
 EXTERN_MSC void GMT_free_br (struct GMT_BR *c);
 EXTERN_MSC void GMT_shore_cleanup (struct GMT_SHORE *c);
 EXTERN_MSC void GMT_br_cleanup (struct GMT_BR *c);
 EXTERN_MSC int GMT_init_shore (char res, struct GMT_SHORE *c, double w, double e, double s, double n);
 EXTERN_MSC int GMT_init_br (char which, char res, struct GMT_BR *c, double w, double e, double s, double n);
-EXTERN_MSC int GMT_assemble_shore (struct GMT_SHORE *c, int dir, int first_level, BOOLEAN assemble, BOOLEAN shift, double west, double east, struct POL **pol);
-EXTERN_MSC int GMT_assemble_br (struct GMT_BR *c, BOOLEAN shift, double edge, struct POL **pol);
-EXTERN_MSC int GMT_prep_polygons (struct POL **p, int np, BOOLEAN greenwich, BOOLEAN sample, double step, int anti_bin);
+EXTERN_MSC int GMT_assemble_shore (struct GMT_SHORE *c, int dir, int first_level, BOOLEAN assemble, BOOLEAN shift, double west, double east, struct GMT_GSHHS_POL **pol);
+EXTERN_MSC int GMT_assemble_br (struct GMT_BR *c, BOOLEAN shift, double edge, struct GMT_GSHHS_POL **pol);
+EXTERN_MSC int GMT_prep_polygons (struct GMT_GSHHS_POL **p, int np, BOOLEAN greenwich, BOOLEAN sample, double step, int anti_bin);
 EXTERN_MSC int GMT_set_resolution (char *res, char opt);
 
 #endif /* _GMT_SHORE_H */
