@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: grdcontour.c,v 1.87 2006/04/13 08:34:41 pwessel Exp $
+ *	$Id: grdcontour.c,v 1.94 2006/10/30 18:09:29 pwessel Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -34,6 +34,7 @@
  * Revised:	25-JUN-2000 for GMT 3.3.5
  * Version:	3.4 Added Kaj Jancke's modification for transparent label boxes
  * Version:	4.0 15-JUL-2004 Implemented label clipping in PostScript. Expeanded -G option
+ * Version:	4.1.x
  *
  */
 
@@ -272,17 +273,23 @@ int main (int argc, char **argv)
 					j = (argv[i][k] == 'a' || argv[i][k] == 'c') ? k+1 : k;
 					if (j == k) {	/* Set both */
 						if (GMT_getpen (&argv[i][j], &Ctrl->W.pen[0])) {
-							GMT_pen_syntax ('W');
+							GMT_pen_syntax ('W', " ");
 							error++;
 						}
 						else Ctrl->W.pen[1] = Ctrl->W.pen[0];
 					}
-					else {
+					else {	/* Gave a or c.  Because the user may say -Wcyan we must prevent this from being seen as -Wc and color yan! */
+						/* Get the argument following a or c and up to first comma, slash (or to the end) */
+						n = k+1;
+						while (!(argv[i][n] == ',' || argv[i][n] == '/' || argv[i][n] == '\0')) n++;
+						strncpy (txt_a, &argv[i][k], n-k);	txt_a[n-k] = '\0';
+						if (GMT_colorname2index (txt_a) >= 0) j = k;	/* Found a colorname; wind j back by 1 */
 						id = (argv[i][k] == 'a') ? 1 : 0;
 						if (GMT_getpen (&argv[i][j], &Ctrl->W.pen[id])) {
-							GMT_pen_syntax ('W');
+							GMT_pen_syntax ('W', " ");
 							error++;
 						}
+						if (j == k) Ctrl->W.pen[1] = Ctrl->W.pen[0];	/* Must copy since it wasnt -Wc or -Wa after all */
 					}
 					break;
 				case 'Z':
@@ -352,8 +359,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   for local Lows and Highs (e.g, give :-+ to plot - and + signs)\n");
 		GMT_explain_option ('U');
 		GMT_explain_option ('V');
-		fprintf (stderr, "\t-W sets pen attributes. <type> can be 'a' for annotated contours and\n");
-		fprintf (stderr, "\t   'c' for regular contours.  The default settings are\n");
+		GMT_pen_syntax ('W', "sets pen attributes. Append a<pen> for annotated contours or c<pen> for regular contours [Default]");
+		fprintf (stderr, "\t   The default settings are\n");
 		fprintf (stderr, "\t   Contour pen:  width = %gp, color = (%d/%d/%d), texture = solid\n", Ctrl->W.pen[0].width, Ctrl->W.pen[0].rgb[0], Ctrl->W.pen[0].rgb[1], Ctrl->W.pen[0].rgb[2]);
 		fprintf (stderr, "\t   Annotate pen: width = %gp, color = (%d/%d/%d), texture = solid\n", Ctrl->W.pen[1].width, Ctrl->W.pen[1].rgb[0], Ctrl->W.pen[1].rgb[1], Ctrl->W.pen[1].rgb[2]);
 		fprintf (stderr, "\t   Use + to draw colored contours based on the cpt file\n");
@@ -411,6 +418,10 @@ int main (int argc, char **argv)
 	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
 
 
+	if (Ctrl->D.active && Ctrl->D.file[0] == 0) {
+		fprintf (stderr, "%s: contours will be written to file contour\n", GMT_program);
+		strcpy (Ctrl->D.file,"contour");
+	}
 	GMT_z_periodic = Ctrl->Z.periodic;	/* Phase data */
 	z_project.view_azimuth = Ctrl->E.azimuth;
 	z_project.view_elevation = Ctrl->E.elevation;
@@ -451,9 +462,18 @@ int main (int argc, char **argv)
 	/* Read data */
 
 	if (subset) {	/* Possibly extend the subset by 1 row/col since tiles need 4 corners to work */
-		if (GMT_x_to_i (data_west, header.x_min, header.x_inc, header.xy_off, header.nx) > 0) data_west -= header.x_inc;
-		if (GMT_x_to_i (data_east, header.x_min, header.x_inc, header.xy_off, header.nx) < (header.nx)) data_east += header.x_inc;
-		if (data_east > header.x_max) data_east -= header.x_inc;
+		BOOLEAN global;
+		global = (GMT_io.in_col_type[0] == GMT_IS_LON && fabs (fabs (header.x_max - header.x_min) - 360.0) < GMT_CONV_LIMIT);
+		if (global && data_west > project_info.w)
+			data_west -= header.x_inc;
+		else if (GMT_x_to_i (data_west, header.x_min, header.x_inc, header.xy_off, header.nx) > 0)
+			data_west -= header.x_inc;
+		if (global && data_east < project_info.e)
+			data_east += header.x_inc;
+		else if (GMT_x_to_i (data_east, header.x_min, header.x_inc, header.xy_off, header.nx) < (header.nx)) {
+			data_east += header.x_inc;
+			if (data_east > header.x_max) data_east -= header.x_inc;
+		}
 		if (GMT_y_to_j (data_south, header.y_min, header.y_inc, header.xy_off, header.ny) < (header.ny)) data_south -= header.y_inc;
 		if (GMT_y_to_j (data_north, header.y_min, header.y_inc, header.xy_off, header.ny) > 0) data_north += header.y_inc;
 		if (data_south < header.y_min) data_south += header.y_inc;
@@ -541,7 +561,7 @@ int main (int argc, char **argv)
 		FILE *fpc = NULL;
 
 		n_contours = 0;
-		if ((fpc = GMT_fopen (Ctrl->C.file, "r"))) {
+		if ((fpc = GMT_fopen (Ctrl->C.file, "r")) == NULL) {
 			fprintf (stderr, "%s: Error opening contour info file %s\n", GMT_program, Ctrl->C.file);
 			exit (EXIT_FAILURE);
 		}
