@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: grdedit.c,v 1.27 2006/04/13 08:34:41 pwessel Exp $
+ *	$Id: grdedit.c,v 1.31 2006/10/17 22:04:04 remko Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -42,6 +42,9 @@ struct GRDEDIT_CTRL {
 		BOOLEAN active;
 		char *information;
 	} D;
+	struct E {	/* -E */
+		BOOLEAN active;
+	} E;
 	struct N {	/* N<xyzfile> */
 		BOOLEAN active;
 		char *file;
@@ -56,7 +59,7 @@ struct GRDEDIT_CTRL {
 
 int main (int argc, char **argv)
 {
-	BOOLEAN error = FALSE, got_region = FALSE;
+	BOOLEAN error = FALSE;
 
 	int i, j, k, n_expected_fields, n_fields, n_data;
 
@@ -94,17 +97,19 @@ int main (int argc, char **argv)
   				case 'f':
 				case '\0':
 					error += GMT_parse_common_options (argv[i], &w, &e, &s, &n);
-					if (argv[i][1] == 'R') got_region = TRUE;
 					break;
 
 				/* Supplemental parameters */
 
+				case 'A':
+					Ctrl->A.active = TRUE;
+					break;
 				case 'D':
 					Ctrl->D.active = TRUE;
 					Ctrl->D.information = strdup (&argv[i][2]);
 					break;
-				case 'A':
-					Ctrl->A.active = TRUE;
+				case 'E':
+					Ctrl->E.active = TRUE;
 					break;
 				case 'N':
 					Ctrl->N.active = TRUE;
@@ -127,10 +132,10 @@ int main (int argc, char **argv)
 	}
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
-		fprintf (stderr, "grdedit %s - Modifying the header in a netCDF grdfile\n\n", GMT_VERSION);
+		fprintf (stderr, "grdedit %s - Modifying the header or content of a 2-D grdfile\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: grdedit grdfile [-A] [%s]\n", GMT_GRDEDIT);
-		fprintf (stderr, "\t[%s] [N<xyzfile>] [%s] [-S] [-T] [-V]\n", GMT_H_OPT, GMT_Rgeo_OPT);
-		fprintf (stderr, "\t[%s] [%s] [%s]\n", GMT_t_OPT, GMT_bi_OPT, GMT_f_OPT);
+		fprintf (stderr, "\t[-E] [%s] [-N<xyzfile>] [%s] [-S] [-T]\n", GMT_H_OPT, GMT_Rgeo_OPT);
+		fprintf (stderr, "\t[-V] [%s] [%s] [%s]\n", GMT_t_OPT, GMT_bi_OPT, GMT_f_OPT);
 
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
@@ -138,6 +143,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\n\tOPTIONS:\n");
 		fprintf (stderr, "\t-A will adjust dx/dy to be compatible with the files domain or -R\n");
 		fprintf (stderr, "\t-D to enter information.  Specify '=' to get default value\n");
+		fprintf (stderr, "\t-E to tranpose the entire grid (this will exchange x and y)\n");
 		GMT_explain_option ('H');
 		fprintf (stderr, "\t-N <file> has new xyz values to replace existing grid nodes\n");
 		GMT_explain_option ('R');
@@ -159,6 +165,10 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -S option:  Incompatible with -A\n", GMT_program);
 		error++;
 	}
+	if (Ctrl->E.active && (Ctrl->A.active || Ctrl->D.active || Ctrl->N.active || Ctrl->S.active || Ctrl->T.active)) {
+		fprintf (stderr, "%s: GMT SYNTAX ERROR -E option:  Incompatible with -A, -D, -N, -S, OR -T\n", GMT_program);
+		error++;
+	}
 	if (Ctrl->S.active && Ctrl->T.active) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -S option:  Incompatible with -T\n", GMT_program);
 		error++;
@@ -167,11 +177,11 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -S option:  Incompatible with -N\n", GMT_program);
 		error++;
 	}
-	if (Ctrl->S.active && !got_region) {
+	if (Ctrl->S.active && !project_info.region_supplied) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -S option:  Must also specify -R\n", GMT_program);
 		error++;
 	}
-	if (Ctrl->S.active && fabs (w-e-360.0) > GMT_CONV_LIMIT) {
+	if (Ctrl->S.active && fabs (e-w-360.0) > GMT_CONV_LIMIT) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -S option:  -R longitudes must span exactly 360 degrees\n", GMT_program);
 		error++;
 	}
@@ -181,7 +191,7 @@ int main (int argc, char **argv)
 	}
 	if (Ctrl->N.active) {
 		if (!Ctrl->N.file) {
-			fprintf (stderr, "%s: GMT SYNTAX ERROR -N option:  Must specify xyz ASCII file\n", GMT_program);
+			fprintf (stderr, "%s: GMT SYNTAX ERROR -N option:  Must specify name of xyz file\n", GMT_program);
 			error++;
 		}
 		if (GMT_io.binary[GMT_IN] && GMT_io.io_header[GMT_IN]) {
@@ -279,8 +289,46 @@ int main (int argc, char **argv)
 		}
 		GMT_free ((void *)a);
 	}
+	else if (Ctrl->E.active) {	/* Transpose the matrix and exchange x and y info */
+		struct GRD_HEADER grd_tr;
+		int row, col, ij, ij_tr;
+		float *a_tr;
+		
+		a = (float *) GMT_memory (VNULL, (size_t)(grd.nx * grd.ny), sizeof (float), GMT_program);
+		a_tr = (float *) GMT_memory (VNULL, (size_t)(grd.ny * grd.nx), sizeof (float), GMT_program);
+		if (GMT_read_grd (grdfile, &grd, a, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
+			fprintf (stderr, "%s: Error reading file %s\n", GMT_program, grdfile);
+			exit (EXIT_FAILURE);
+		}
+		memcpy ((void *)&grd_tr, (void *)&grd, sizeof (struct GRD_HEADER));	/* First make a copy of header */
+		grd_tr.nx = grd.ny;	/* Then exchange x and y values */
+		grd_tr.x_min = grd.y_min;
+		grd_tr.x_max = grd.y_max;
+		grd_tr.x_inc = grd.y_inc;
+		strcpy (grd_tr.x_units, grd.y_units);
+		grd_tr.ny = grd.nx;
+		grd_tr.y_min = grd.x_min;
+		grd_tr.y_max = grd.x_max;
+		grd_tr.y_inc = grd.x_inc;
+		strcpy (grd_tr.y_units, grd.x_units);
+		/* Now transpose the matrix */
+		
+		for (row = 0; row < grd.ny; row++) {
+			for (col = 0; col < grd.nx; col++) {
+				ij = row * grd.nx + col;
+				ij_tr = col * grd.ny + row;
+				a_tr[ij_tr] = a[ij];
+			}
+		}
+		if (GMT_write_grd (grdfile, &grd_tr, a_tr, 0.0, 0.0, 0.0, 0.0, GMT_pad, FALSE)) {
+			fprintf (stderr, "%s: Error writing file %s\n", GMT_program, grdfile);
+			exit (EXIT_FAILURE);
+		}
+		GMT_free ((void *)a);
+		GMT_free ((void *)a_tr);
+	}
 	else {
-		if (got_region) {
+		if (project_info.region_supplied) {
 			if (gmtdefs.verbose) fprintf (stderr, "%s: Reset region in file %s to %g/%g/%g/%g\n",
 				GMT_program, grdfile, w, e, s, n);
 			grd.x_min = w;	grd.x_max = e;
