@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: grdfilter.c,v 1.44 2006/05/12 04:15:12 pwessel Exp $
+ *	$Id: grdfilter.c,v 1.46 2006/10/06 17:19:36 pwessel Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -97,13 +97,13 @@ int main (int argc, char **argv)
 	int	filter_type, one_or_zero = 1, GMT_n_multiples = 0, *i_origin;
 
 
-	BOOLEAN	error, new_range, fast_way, shift = FALSE, slow = FALSE;
-	BOOLEAN wrap_case = FALSE, pole_check = FALSE;
-	BOOLEAN full_360, duplicate_check, i_west_used, i_east_used, row_ok;
+	BOOLEAN	error, new_range, fast_way, slow = FALSE;
+	BOOLEAN wrap_case_x = FALSE, wrap_case_y = FALSE, pole_check = FALSE;
+	BOOLEAN full_360, full_180, duplicate_check, i_west_used, i_east_used, row_ok;
 
 	float	*input, *output;
 
-	double	west_new, east_new, south_new, north_new, offset;
+	double	west_new, east_new, south_new, north_new;
 	double	x_scale, y_scale, x_width, y_width, y, par[5], pole_weight;
 	double	x_out, y_out, wt_sum, value, last_median, this_median, xincnew2, yincnew2;
 	double	xincold2, yincold2, y_shift = 0.0, x_fix = 0.0, y_fix = 0.0;
@@ -362,14 +362,13 @@ int main (int argc, char **argv)
 	yincnew2 = (one_or_zero) ? 0.0 : 0.5 * Ctrl->I.yinc;
 	xincold2 = (h.node_offset) ? 0.5 * h.x_inc : 0.0;
 	yincold2 = (h.node_offset) ? 0.5 * h.y_inc : 0.0;
-	offset = (h.node_offset) ? 0.5 : 0.0;
 
 	if (fast_way && h.node_offset == one_or_zero) {	/* multiple grid but one is pix, other is grid */
 		x_fix = 0.5 * h.x_inc;
 		y_fix = 0.5 * h.y_inc;
-		shift = (x_fix != 0.0 || y_fix != 0.0);
 	}
 	full_360 = (Ctrl->D.mode && fabs (fabs (h.x_max - h.x_min) - 360.0) < GMT_CONV_LIMIT);	/* Periodic geographic grid */
+	full_180 = (Ctrl->D.mode && fabs (fabs (h.y_max - h.y_min) - 180.0) < GMT_CONV_LIMIT);	/* Full latitude range for geographic grid */
 
 	/* Set up the distance scalings for lon and lat, and assign pointer to distance function  */
 
@@ -396,7 +395,8 @@ int main (int argc, char **argv)
 			x_scale = 0.0;
 			y_scale = project_info.KM_PR_DEG;
 			F.radius_func = SphericalRadius;
-			if (full_360) wrap_case = TRUE;	/* For spherical filtering */
+			if (full_360) wrap_case_x = TRUE;		/* For spherical filtering */
+			if (full_180) wrap_case_y = wrap_case_x;	/* For spherical filtering */
 			break;
 	}
 			
@@ -513,7 +513,7 @@ int main (int argc, char **argv)
 			i_west_used = i_east_used = FALSE;
 			for (ii = -F.x_half_width; ii <= F.x_half_width; ii++) {
 				i_in = i_origin[i_out] + ii;
-				if (wrap_case) {	/* Just wrap around the globe */
+				if (wrap_case_x) {	/* Just wrap around the globe */
 					if (i_in < 0) i_in += h.nx;
 					if (i_in >= h.nx) i_in -= h.nx;
 					i_orig = i_in;
@@ -543,7 +543,7 @@ int main (int argc, char **argv)
 						continue;	/* Done with this row */
 					}
 						
-					if (wrap_case) {	/* Just wrap over the pole */
+					if (wrap_case_y) {	/* Just wrap over the pole */
 						i_in = i_orig;
 						if (j_in < 0) j_in = -j_in, i_in += half_nx;
 						if (j_in >= h.ny) j_in = 2*h.ny - j_in - 2, i_in += half_nx;
