@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: grdsample.c,v 1.35 2006/04/13 08:34:41 pwessel Exp $
+ *	$Id: grdsample.c,v 1.41 2006/10/17 22:10:42 remko Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -58,11 +58,11 @@ struct GRDSAMPLE_CTRL {
 
 int main (int argc, char **argv)
 {
-	BOOLEAN error = FALSE, greenwich = FALSE, area_set = FALSE, n_set = FALSE, node = FALSE;
+	BOOLEAN error = FALSE, node = FALSE;
 
 	char *infile = CNULL, format[BUFSIZ];
 
-	int i, j, ii, jj, mx = 0;
+	int i, j, ii = 0, jj = 0, mx = 0;
 
 	size_t ij, k, nm;
 	
@@ -108,9 +108,11 @@ int main (int argc, char **argv)
 					Ctrl->G.file = strdup (&argv[i][2]);
 					break;
 				case 'N':	/* Backwards compatible.  nx/ny can now be set with -I */
-					sscanf (&argv[i][2], "%d/%d", &grd_b.nx, &grd_b.ny);
-					if (grd_b.ny == 0) grd_b.ny = grd_b.nx;
-					n_set = TRUE;
+					Ctrl->I.active = TRUE;
+					sscanf (&argv[i][2], "%d/%d", &ii, &jj);
+					if (jj == 0) jj = ii;
+					sprintf (format, "%d+/%d+", ii, jj);
+					GMT_getinc (format, &Ctrl->I.xinc, &Ctrl->I.yinc);
 					break;
 				case 'I':
 					Ctrl->I.active = TRUE;
@@ -150,8 +152,9 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t<old_grdfile> is data set to be resampled\n");
 		fprintf (stderr, "\t-G sets the name of the interpolated output grdfile\n");
 		fprintf (stderr, "\n\tOPTIONS:\n");
-		fprintf (stderr, "\t-F force pixel node registration  [Default is centered]\n");
+		fprintf (stderr, "\t-F Force pixel registration  [Default is same as input]\n");
 		GMT_inc_syntax ('I', 0);
+		fprintf (stderr, "\t   When omitted: grid spacing is copied from input grid.\n");
 		fprintf (stderr, "\t-L sets boundary conditions.  <flag> can be either\n");
 		fprintf (stderr, "\t   g for geographic boundary conditions\n");
 		fprintf (stderr, "\t   or one or both of\n");
@@ -165,10 +168,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   nearest node instead of interpolating.\n");
 		fprintf (stderr, "\t-R specifies a subregion [Default is old region]\n");
 		fprintf (stderr, "\t-T Toggles between grid registration and pixel registration\n");
-		fprintf (stderr, "\t   In this case, -I is ignored.\n");
 		GMT_explain_option ('V');
 		GMT_explain_option ('f');
-		fprintf (stderr, "\t   One only of -N -I must be specified\n");
 
 		exit (EXIT_FAILURE);
 	}
@@ -185,82 +186,66 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -G:  Must specify output file\n", GMT_program);
 		error++;
 	}
-	if (Ctrl->L.active && GMT_boundcond_parse (&edgeinfo, Ctrl->L.mode)) error++;
-
-	if (grd_b.x_min != grd_b.x_max && grd_b.y_min != grd_b.y_max) area_set = TRUE;
-	if (Ctrl->I.active) {
-		grd_b.x_inc = Ctrl->I.xinc;
-		grd_b.y_inc = Ctrl->I.yinc;
+	if (Ctrl->F.active && Ctrl->T.active) {
+		fprintf (stderr, "%s: GMT SYNTAX ERROR:  Only one of -F, -T may be specified\n", GMT_program);
+		error++;
 	}
+	if (Ctrl->I.active && (Ctrl->I.xinc <= 0.0 || Ctrl->I.yinc <= 0.0)) {
+		fprintf (stderr, "%s: GMT SYNTAX ERROR -I:  Must specify positive increments\n", GMT_program);
+		error++;
+	}
+	if (Ctrl->L.active && GMT_boundcond_parse (&edgeinfo, Ctrl->L.mode)) error++;
+	if (error) exit (EXIT_FAILURE);
 	
 	if (GMT_read_grd_info (infile, &grd_a)) {
 		fprintf (stderr, "%s: Error opening file %s\n", GMT_program, infile);
 		exit (EXIT_FAILURE);
 	}
 
-	if (!area_set) {
+	if (!project_info.region_supplied) {
 		grd_b.x_min = grd_a.x_min;
 		grd_b.x_max = grd_a.x_max;
 		grd_b.y_min = grd_a.y_min;
 		grd_b.y_max = grd_a.y_max;
 	}
-	if (!Ctrl->T.active) {
-		if (Ctrl->I.active && n_set) {
-			fprintf (stderr, "%s: GMT SYNTAX ERROR:  Only one of -I, -N may be specified\n", GMT_program);
-			error++;
-		}
-		if (n_set && (grd_b.nx <= 0 || grd_b.ny <= 0)) {
-			fprintf (stderr, "%s: GMT SYNTAX ERROR -N:  Must specify positive integers\n", GMT_program);
-			error++;
-		}
-		if (Ctrl->I.active) GMT_RI_prepare (&grd_b);	/* Ensure -R -I consistency and set nx, ny */
-		if (Ctrl->I.active && (grd_b.x_inc <= 0.0 || grd_b.y_inc <= 0.0)) {
-			fprintf (stderr, "%s: GMT SYNTAX ERROR -I:  Must specify positive increments\n", GMT_program);
-			error++;
-		}
-		if (!(Ctrl->I.active || n_set)) {
-			fprintf (stderr, "%s: GMT SYNTAX ERROR:  One of -I, -N must be specified\n", GMT_program);
-			error++;
-		}
+
+	if (Ctrl->I.active) {
+		grd_b.x_inc = Ctrl->I.xinc;
+		grd_b.y_inc = Ctrl->I.yinc;
+	}
+	else {
+		grd_b.x_inc = grd_a.x_inc;
+		grd_b.y_inc = grd_a.y_inc;
 	}
 
-	if (error) exit (EXIT_FAILURE);
+	if (Ctrl->T.active)
+		grd_b.node_offset = !grd_a.node_offset;
+	else if (Ctrl->F.active)
+		grd_b.node_offset = TRUE;
+	else
+		grd_b.node_offset = grd_a.node_offset;
+
+	grd_b.xy_off = 0.5 * grd_b.node_offset;
+
+	GMT_RI_prepare (&grd_b);	/* Ensure -R -I consistency and set nx, ny */
 
 	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
 
 	GMT_boundcond_param_prep (&grd_a, &edgeinfo);
 
-	if (Ctrl->T.active) {
-		Ctrl->F.active = !grd_a.node_offset;	/* Change to the opposite of what it is */
-		grd_b.nx = (Ctrl->F.active) ? grd_a.nx - 1 : grd_a.nx + 1;
-		grd_b.ny = (Ctrl->F.active) ? grd_a.ny - 1 : grd_a.ny + 1;
-		area_set = Ctrl->I.active = FALSE;
-	}
-
 	a = (float *) GMT_memory (VNULL, (size_t)((grd_a.nx + 4) * (grd_a.ny + 4)), sizeof(float), GMT_program);
 
-	if (area_set) {
-		if (grd_b.y_min < grd_a.y_min || grd_b.y_max > grd_a.y_max) {
-			fprintf (stderr, "%s:  Selected region exceeds the boundaries of the grdfile!\n", GMT_program);
+	if (project_info.region_supplied) {
+		if (!edgeinfo.nxp && (grd_b.x_min < grd_a.x_min || grd_b.x_max > grd_a.x_max)) {
+			fprintf (stderr, "%s:  Selected region exceeds the X-boundaries of the grdfile!\n", GMT_program);
 			exit (EXIT_FAILURE);
 		}
-		else if (!edgeinfo.nxp && (grd_b.x_min < grd_a.x_min || grd_b.x_max > grd_a.x_max)) {
-			fprintf (stderr, "%s:  Selected region exceeds the boundaries of the grdfile!\n", GMT_program);
+		else if (!edgeinfo.nyp && (grd_b.y_min < grd_a.y_min || grd_b.y_max > grd_a.y_max)) {
+			fprintf (stderr, "%s:  Selected region exceeds the Y-boundaries of the grdfile!\n", GMT_program);
 			exit (EXIT_FAILURE);
 		}
 	}
 
-	if (!Ctrl->F.active && !Ctrl->T.active) Ctrl->F.active = grd_a.node_offset;
-	grd_b.node_offset = Ctrl->F.active;
-	grd_b.xy_off = 0.5 * grd_b.node_offset;
-
-	if (edgeinfo.nxp && grd_b.x_min < 0.0 && grd_b.x_max > 0.0)
-		greenwich = TRUE;
-	else if (edgeinfo.nxp && grd_b.x_max > 360.0) {
-		greenwich = TRUE;
-		grd_b.x_min -= 360.0;
-		grd_b.x_max -= 360.0;
-	}
 	if (!Ctrl->I.active) {
 		grd_b.x_inc = GMT_get_inc (grd_b.x_min, grd_b.x_max, grd_b.nx, grd_b.node_offset);
 		grd_b.y_inc = GMT_get_inc (grd_b.y_min, grd_b.y_max, grd_b.ny, grd_b.node_offset);
@@ -271,8 +256,8 @@ int main (int argc, char **argv)
 	nm = ((size_t)grd_b.nx) * ((size_t)grd_b.ny);
 	b = (float *) GMT_memory (VNULL, nm, sizeof(float), GMT_program);
 
-	sprintf (format, "%%s: New grid (%s/%s/%s/%s) nx = %%d ny = %%d dx = %s dy = %s\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
-	if (gmtdefs.verbose) fprintf (stderr, format, GMT_program, grd_b.x_min, grd_b.x_max, grd_b.y_min, grd_b.y_max, grd_b.nx, grd_b.ny, grd_b.x_inc, grd_b.y_inc);
+	sprintf (format, "%%s: New grid (%s/%s/%s/%s) nx = %%d ny = %%d dx = %s dy = %s node_offset = %%d\n", gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format, gmtdefs.d_format);
+	if (gmtdefs.verbose) fprintf (stderr, format, GMT_program, grd_b.x_min, grd_b.x_max, grd_b.y_min, grd_b.y_max, grd_b.nx, grd_b.ny, grd_b.x_inc, grd_b.y_inc, grd_b.node_offset);
 
 	GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 2;	/* Leave room for 2 empty boundary rows/cols */
 
@@ -294,7 +279,12 @@ int main (int argc, char **argv)
 	lon = (double *) GMT_memory (VNULL, (size_t)grd_b.nx, sizeof (double), GMT_program);
 	for (i = 0; i < grd_b.nx; i++) {
 		lon[i] = GMT_i_to_x (i, grd_b.x_min, grd_b.x_max, grd_b.x_inc, grd_b.xy_off, grd_b.nx);
-		if (edgeinfo.nxp && greenwich && lon[i] > 180.0) lon[i] -= 360.0;
+		if (!edgeinfo.nxp)
+			/* Nothing */;
+		else if (lon[i] > grd_a.x_max)
+			lon[i] -= grd_a.x_inc * edgeinfo.nxp;
+		else if (lon[i] < grd_a.x_min)
+			lon[i] += grd_a.x_inc * edgeinfo.nxp;
 	}
 
 	if (Ctrl->Q.value == 0.0) {
@@ -304,6 +294,12 @@ int main (int argc, char **argv)
 	
 	for (j = ij = 0; j < grd_b.ny; j++) {
 		lat = GMT_j_to_y (j, grd_b.y_min, grd_b.y_max, grd_b.y_inc, grd_b.xy_off, grd_b.ny);
+		if (!edgeinfo.nyp)
+			/* Nothing */;
+		else if (lat > grd_a.y_max)
+			lat -= grd_a.y_inc * edgeinfo.nyp;
+		else if (lat < grd_a.y_min)
+			lat += grd_a.y_inc * edgeinfo.nyp;
 		for (i = 0; i < grd_b.nx; i++, ij++) {
 			if (node) {
 				ii = GMT_x_to_i (lon[i], grd_a.x_min, grd_a.x_inc, grd_a.xy_off, grd_a.nx);
