@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: grdview.c,v 1.54 2006/05/15 23:48:19 pwessel Exp $
+ *	$Id: grdview.c,v 1.59 2006/10/30 18:34:42 pwessel Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -298,7 +298,7 @@ int main (int argc, char **argv)
 						Ctrl->T.outline = TRUE;
 						k++;
 						if (argv[i][k] && GMT_getpen (&argv[i][k], &Ctrl->T.pen)) {
-							GMT_pen_syntax ('T');
+							GMT_pen_syntax ('T', " ");
 							error++;
 						}
 					}
@@ -308,21 +308,30 @@ int main (int argc, char **argv)
 					j = (argv[i][2] == 'm' || argv[i][2] == 'c') ? 3 : 2;
                                         if (j == 2) {   /* Set both */
 						if (GMT_getpen (&argv[i][2], &Ctrl->W.pen[0])) {
-							GMT_pen_syntax ('W');
+							GMT_pen_syntax ('W', " ");
 							error++;
 						}
 						else
 							Ctrl->W.pen[1] = Ctrl->W.pen[0];
 						Ctrl->W.contour = TRUE;
 					}
-					else {
+					else {	/* Here , j = 3.  BUT: First check that the m or c is not part of a color name instead */
+						char txt_a[GMT_LONG_TEXT];
+						n = j+1;
+						while (!(argv[i][n] == ',' || argv[i][n] == '/' || argv[i][n] == '\0')) n++;
+						strncpy (txt_a, &argv[i][2], n-2);	txt_a[n-2] = '\0';
+						if (GMT_colorname2index (txt_a) >= 0) j = 2;	/* Found a colorname; reset j to 2 */
 						id = (argv[i][2] == 'm') ? 1 : 0;
 						if (GMT_getpen (&argv[i][j], &Ctrl->W.pen[id])) {
-							GMT_pen_syntax ('W');
+							GMT_pen_syntax ('W', " ");
 							error++;
 						}
-						if (id == 0) Ctrl->W.contour = TRUE;
-
+						if (j == 2) {	/* We discovered it wasnt -Wc or -Wm after all so copy pen */
+							Ctrl->W.pen[1] = Ctrl->W.pen[0];
+							Ctrl->W.contour = TRUE;
+						}
+						else if (id == 0)
+							Ctrl->W.contour = TRUE;
 					}
 					break;
 				case 'Z':
@@ -389,18 +398,18 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   To force a monochrome image using the GMT_YIQ transformation, append g\n");
 		GMT_explain_option ('R');
 		fprintf (stderr, "\t-S will smooth contours first (see grdcontour for <smooth> value info).\n");
-		fprintf (stderr, "\t-T will image the data without interpolation by painting polygonal tiles\n");
-		fprintf (stderr, "\t   Append s to skip nodes that are NaN [Default paints all tiles]\n");
-		fprintf (stderr, "\t   Append o[<pen>] to draw tile outline [Default uses no outline]\n");
+		GMT_pen_syntax ('T', "will image the data without interpolation by painting polygonal tiles\n\t   Append s to skip tiles for nodes with z = NaN [Default paints all tiles]\n\t   Append o[<pen>] to draw tile outline [Default uses no outline]");
+		GMT_explain_option ('U');
 		GMT_explain_option ('U');
 		GMT_explain_option ('V');
-		fprintf (stderr, "\t-W sets pen attributes. <type> can be c for contours or m for mesh\n");
-		fprintf (stderr, "\t   -Wc draw scontours on top of surface or mesh.  [Default is no contours]\n");
+		GMT_pen_syntax ('W', "sets pen attributes for contours in form <type><pen> [Default is no contours]");
+		fprintf (stderr, "\t   <type> can be c for contours or m for mesh\n");
+		fprintf (stderr, "\t   c draw scontours on top of surface or mesh.  [Default is no contours]\n");
 		fprintf (stderr, "\t     Optionally append pen attributes [width = %gp, color = (%d/%d/%d), solid line].\n", 
 			Ctrl->W.pen[0].width, Ctrl->W.pen[0].rgb[0], Ctrl->W.pen[0].rgb[1], Ctrl->W.pen[0].rgb[2]);
-		fprintf (stderr, "\t   -Wm sets attributes for mesh lines [[width = %gp, color = (%d/%d/%d), solid line].\n", 
+		fprintf (stderr, "\t   m sets attributes for mesh lines [[width = %gp, color = (%d/%d/%d), solid line].\n", 
 			Ctrl->W.pen[1].width, Ctrl->W.pen[1].rgb[0], Ctrl->W.pen[1].rgb[1], Ctrl->W.pen[1].rgb[2]);
-		fprintf (stderr, "\t      Requires -Qm or -Qsm to take effect.\n");
+		fprintf (stderr, "\t     Requires -Qm or -Qsm to take effect.\n");
 		GMT_explain_option ('X');
 		fprintf (stderr, "\t-Z For 3-D plots: Set the z-level of map [0]\n");
 		GMT_explain_option ('c');
@@ -537,9 +546,18 @@ int main (int argc, char **argv)
 	/* Read data */
 
 	if (subset) {	/* Possibly extend the subset by 1 row/col since tiles need 4 corners to work */
-		if (GMT_x_to_i (data_west, t_head.x_min, t_head.x_inc, t_head.xy_off, t_head.nx) > 0) data_west -= t_head.x_inc;
-		if (GMT_x_to_i (data_east, t_head.x_min, t_head.x_inc, t_head.xy_off, t_head.nx) < (t_head.nx)) data_east += t_head.x_inc;
-		if (data_east > t_head.x_max) data_east -= t_head.x_inc;
+		BOOLEAN global;
+		global = (GMT_io.in_col_type[0] == GMT_IS_LON && fabs (fabs (t_head.x_max - t_head.x_min) - 360.0) < GMT_CONV_LIMIT);
+		if (global && data_west > project_info.w)
+			data_west -= t_head.x_inc;
+		else if (GMT_x_to_i (data_west, t_head.x_min, t_head.x_inc, t_head.xy_off, t_head.nx) > 0)
+			data_west -= t_head.x_inc;
+		if (global && data_east < project_info.e)
+			data_east += t_head.x_inc;
+		else if (GMT_x_to_i (data_east, t_head.x_min, t_head.x_inc, t_head.xy_off, t_head.nx) < (t_head.nx)) {
+			data_east += t_head.x_inc;
+			if (data_east > t_head.x_max) data_east -= t_head.x_inc;
+		}
 		if (GMT_y_to_j (data_south, t_head.y_min, t_head.y_inc, t_head.xy_off, t_head.ny) < (t_head.ny)) data_south -= t_head.y_inc;
 		if (GMT_y_to_j (data_north, t_head.y_min, t_head.y_inc, t_head.xy_off, t_head.ny) > 0) data_north += t_head.y_inc;
 		if (data_south < t_head.y_min) data_south += t_head.y_inc;
