@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: makecpt.c,v 1.23 2006/04/12 21:55:46 pwessel Exp $
+ *	$Id: makecpt.c,v 1.28 2006/10/25 21:56:22 pwessel Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -40,6 +40,9 @@ struct MAKECPT_CTRL {
 	struct I {	/* -I */
 		BOOLEAN active;
 	} I;
+	struct M {	/* -M */
+		BOOLEAN active;
+	} M;
 	struct N {	/* -N */
 		BOOLEAN active;
 	} N;
@@ -60,7 +63,7 @@ struct MAKECPT_CTRL {
 
 int main(int argc, char **argv)
 {
-	int	i, nz, cpt_flags = 0;
+	int	i, nz;
 
 	BOOLEAN	error = FALSE;
 
@@ -78,10 +81,9 @@ int main(int argc, char **argv)
 
 	Ctrl = (struct MAKECPT_CTRL *)New_Makecpt_Ctrl ();	/* Allocate and initialize a new control structure */
 	
-	/* Get list of available color tables in $GMTHOME/share/cpt */
-
-	sprintf (CPT_lis, "%s%cshare%cGMT_CPT.lis", GMTHOME, DIR_DELIM, DIR_DELIM);
+	/* Get list of available color tables in $GMTHOME/share */
 
+	GMT_getsharepath (CNULL, "GMT_CPT", ".lis", CPT_lis);
 	if ((fpc = fopen (CPT_lis, "r")) == NULL) {
 		fprintf (stderr, "%s: ERROR: Cannot open file %s\n", GMT_program, CPT_lis);
 		exit (EXIT_FAILURE);
@@ -104,6 +106,9 @@ int main(int argc, char **argv)
 				case 'I':
 					Ctrl->I.active = TRUE;
 					break;
+				case 'M':
+					Ctrl->M.active = TRUE;
+					break;
 				case 'N':
 					Ctrl->N.active = TRUE;
 					break;
@@ -134,7 +139,7 @@ int main(int argc, char **argv)
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "makecpt %s - Make GMT color palette tables\n\n", GMT_VERSION);
-		fprintf (stderr, "usage:  makecpt [-C<table>] [-D] [-I] [-N] [-Q[i|o]] [-T<z0/z1/dz> | -T<file>] [-V] [-Z]\n\n");
+		fprintf (stderr, "usage:  makecpt [-C<table>] [-D] [-I] [-M] [-N] [-Q[i|o]] [-T<z0/z1/dz> | -T<file>] [-V] [-Z]\n");
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 		fprintf (stderr, "\n\tOPTIONS:\n");
 		fprintf (stderr, "\t-C Specify a colortable [Default is rainbow]:\n");
@@ -143,18 +148,18 @@ int main(int argc, char **argv)
 		while (fgets (buffer, BUFSIZ, fpc)) if (!(buffer[0] == '#' || buffer[0] == 0)) fprintf (stderr, "\t   %s", buffer);
 		fclose (fpc);
 		fprintf (stderr, "\t   ---------------------------------\n");
-		fprintf (stderr, "\t-D Set back- and foreground color to match the bottom/top limits in the cpt file [Default uses GMT defaults]:\n");
-		fprintf (stderr, "\t-I reverses the sense of the color table\n");
-		fprintf (stderr, "\t-N Do Not write back-, fore-, and nan colors [Default will].\n");
-		fprintf (stderr, "\t-Q assign a logarithmic colortable [Default is linear]\n");
+		fprintf (stderr, "\t-D Set back- and foreground color to match the bottom/top limits in the cpt file [Default uses color table].\n");
+		fprintf (stderr, "\t-I Reverses the sense of the color table as well as back- and foreground color.\n");
+		fprintf (stderr, "\t-M Use GMT defaults to set back-, foreground, and NaN colors [Default uses color table].\n");
+		fprintf (stderr, "\t-N Do not write back-, foreground, and NaN colors [Default will].\n");
+		fprintf (stderr, "\t-Q Assign a logarithmic colortable [Default is linear]\n");
 		fprintf (stderr, "\t   -Qi: z-values are actually log10(z). Assign colors and write z. [Default]\n");
 		fprintf (stderr, "\t   -Qo: z-values are z, but take log10(z), assign colors and write z.\n");
 		fprintf (stderr, "\t        If -T<z0/z1/dz> is given, dz is 1, 2, or 3 (as in logarithmic anotations)\n");
 		fprintf (stderr, "\t-T Give start, stop, and increment for colorscale in z-units, or filename with custom z-values\n");
 		fprintf (stderr, "\t   If not given, the range in the master cptfile is used\n");
 		GMT_explain_option ('V');
-		fprintf (stderr, "\t-Z will create a continuous color palette.\n");
-		fprintf (stderr, "\t   [Default is discontinuous, i.e., constant color intervals]\n");
+		fprintf (stderr, "\t-Z Create a continuous color palette [Default is discontinuous, i.e., constant color intervals]\n");
 		exit (EXIT_FAILURE);
 	}
 
@@ -164,7 +169,10 @@ int main(int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -T option:  Give start < stop and inc > 0.0\n", GMT_program);
 		error++;
 	}
-
+	if (!Ctrl->C.active) {	/* Set default table */
+		Ctrl->C.active = TRUE;
+		Ctrl->C.file = strdup ("rainbow");
+	}	
 	error += GMT_set_cpt_path (CPT_file, Ctrl->C.file);
 
 	if (Ctrl->T.file && (fpl = GMT_fopen (Ctrl->T.file, "r")) == NULL) {
@@ -178,11 +186,12 @@ int main(int argc, char **argv)
 
 	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
 
+	if (Ctrl->N.active) GMT_cpt_flags += 1;	/* bit 0 controls if BFN will be written out */
+	if (Ctrl->D.active) GMT_cpt_flags += 2;	/* bit 1 controls if BF will be set to equal bottom/top rgb value */
+	if (Ctrl->M.active) GMT_cpt_flags += 4;	/* bit 2 controls if BFN is determined by parameters */
+
 	GMT_read_cpt (CPT_file);
 
-	if (Ctrl->N.active) cpt_flags |= 1;	/* 1st bit controls if BFN will be written out */
-	if (Ctrl->D.active) cpt_flags |= 2;	/* 2nd bit controls if BF will be set to equal bottom/top rgb value */
-	
 	/* Set up arrays */
 
 	if (Ctrl->T.file) {
@@ -237,7 +246,7 @@ int main(int argc, char **argv)
 	for (i = 1; i < argc; i++) fprintf (GMT_stdout, " %s", argv[i]);
 	fprintf (GMT_stdout, "\n");
 
-	GMT_sample_cpt (z, nz, Ctrl->Z.active, Ctrl->I.active, Ctrl->Q.mode, cpt_flags);
+	GMT_sample_cpt (z, nz, Ctrl->Z.active, Ctrl->I.active, Ctrl->Q.mode);
 
 	GMT_free ((void *)z);
 
