@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *    $Id: psmeca.c,v 1.27 2006/04/10 05:47:30 pwessel Exp $
+ *    $Id: psmeca.c,v 1.28 2006/10/11 02:52:17 remko Exp $
  *
  *    Copyright (c) 1996-2001 by G. Patau
  *    See README file for copying and redistribution conditions.
@@ -159,7 +159,7 @@ int main (int argc, char **argv)
                             strcpy(txt_a, &argv[i][2]);
                             n=0; while (txt_a[n] != 'P') n++; txt_a[n]=0;
                             if (GMT_getpen (txt_a, &cpen)) {
-                                GMT_pen_syntax ('C');
+                                GMT_pen_syntax ('C', " ");
                                 error++;
                             }
                         }
@@ -170,13 +170,13 @@ int main (int argc, char **argv)
                     break;
                 case 'E':    /* Set color for extensive parts  */
                     if (!argv[i][2] || (argv[i][2] && GMT_getfill (&argv[i][2], &efill))) {
-                        GMT_fill_syntax ('G');
+                        GMT_fill_syntax ('G', " ");
                         error++;
                     }
                     break;
                 case 'G':    /* Set color for compressive parts */
                     if (!argv[i][2] || (argv[i][2] && GMT_getfill (&argv[i][2], &fill))) {
-                        GMT_fill_syntax ('G');
+                        GMT_fill_syntax ('G', " ");
                         error++;
                     }
                     break;
@@ -185,7 +185,7 @@ int main (int argc, char **argv)
                     if (argv[i][2]) {
                         def_lpen = TRUE;
                         if (GMT_getpen (&argv[i][2], &lpen)) {
-                            GMT_pen_syntax ('L');
+                            GMT_pen_syntax ('L', " ");
                             error++;
                         }
                     }
@@ -260,7 +260,7 @@ int main (int argc, char **argv)
                     if(strlen(argv[i]) > 4) { /* Set transparent attributes */
                         def_tr_pen = TRUE;
                         if (GMT_getpen (&argv[i][4], &tr_pen)) {
-                            GMT_pen_syntax ('T');
+                            GMT_pen_syntax ('T', " ");
                             error++;
                         }
                     }
@@ -270,14 +270,14 @@ int main (int argc, char **argv)
                     if(strlen(argv[i]) > 2) { /* Set transparent attributes */
                         def_tz_pen = TRUE;
                         if (GMT_getpen (&argv[i][2], &tz_pen)) {
-                        GMT_pen_syntax ('z');
+                        GMT_pen_syntax ('z', " ");
                             error++;
                         }
                     }
                     break;
                 case 'W':    /* Set line attributes */
                     if (argv[i][2] && GMT_getpen (&argv[i][2], &pen)) {
-                        GMT_pen_syntax ('W');
+                        GMT_pen_syntax ('W', " ");
                         error++;
                     }
                     break;
@@ -373,7 +373,7 @@ int main (int argc, char **argv)
                     if (strlen(argv[i]) > 2) {
                         def_tfill = TRUE;
                         if (GMT_getfill (&argv[i][2], &tfill)) {
-                            GMT_fill_syntax ('e');
+                            GMT_fill_syntax ('e', " ");
                             error++;
                         }
                     }
@@ -382,7 +382,7 @@ int main (int argc, char **argv)
                     if (strlen(argv[i]) > 2) {
                         def_pfill = TRUE;
                         if (GMT_getfill (&argv[i][2], &pfill)) {
-                            GMT_fill_syntax ('g');
+                            GMT_fill_syntax ('g', " ");
                             error++;
                         }
                     }
@@ -392,7 +392,7 @@ int main (int argc, char **argv)
                     if(strlen(argv[i]) > 2) {
                         def_ppen = TRUE;
                         if (GMT_getpen (&argv[i][2], &ppen)) {
-                            GMT_pen_syntax ('p');
+                            GMT_pen_syntax ('p', " ");
                             error++;
                         }
                     }
@@ -402,7 +402,7 @@ int main (int argc, char **argv)
                     if(strlen(argv[i]) > 2){
                         def_tpen = TRUE;
                         if (GMT_getpen (&argv[i][2], &tpen)) {
-                            GMT_pen_syntax ('t');
+                            GMT_pen_syntax ('t', " ");
                             error++;
                         }
                     } 
