@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: dat2gmt.c,v 1.1.1.1 2000/12/28 01:23:45 gmt Exp $
+ *	$Id: dat2gmt.c,v 1.4 2006/03/25 03:56:52 pwessel Exp $
  *
- *    Copyright (c) 1991-2001 by P. Wessel and W. H. F. Smith
+ *    Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -22,15 +22,14 @@
 
 #define MEM_SIZE 50000
 
-struct GMTMGG_REC *record;
-
-main (int argc, char **argv)
+int main (int argc, char **argv)
 {
 	int rec, n_records, leg_year, time, mag, top, yr, mo, dy, hr, mi, sc, n_alloc = MEM_SIZE, conv;
 	double lat, lon, grv;
 	char line[BUFSIZ], agency[10], stime[20], sgrv[10], smag[10], stop[10];
 	FILE *fpi, *fpo;
 	struct GMTMGG_TIME *gmt;
+	struct GMTMGG_REC *record;
 	
 	if (argc != 3 || ((fpi = fopen(argv[1], "r")) == NULL) || ((fpo = fopen(argv[2], "wb")) == NULL)) {
 		fprintf(stderr, "usage: dat2gmt asciifile file.gmt\n");
