@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: makepattern.c,v 1.11 2006/04/10 05:47:30 pwessel Exp $
+ *	$Id: makepattern.c,v 1.12 2006/10/11 02:52:18 remko Exp $
  *
  *      Copyright (c) 1999-2006 by P. Wessel
  *      See COPYING file for copying and redistribution conditions.
@@ -82,13 +82,13 @@ int main (int argc, char **argv)
 					switch (argv[i][2]) {
 						case 'f':
 							if (GMT_getfill (&argv[i][3], &fg)) {
-								GMT_fill_syntax ('C');
+								GMT_fill_syntax ('C', " ");
 								error++;
 							}
 							break;
 						case 'b':
 							if (GMT_getfill (&argv[i][3], &bg)) {
-								GMT_fill_syntax ('C');
+								GMT_fill_syntax ('C', " ");
 								error++;
 							}
 							break;
