@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: pshistogram.c,v 1.43 2006/04/13 08:34:41 pwessel Exp $
+ *	$Id: pshistogram.c,v 1.45 2006/10/11 02:25:13 remko Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -52,6 +52,7 @@ struct PSHISTOGRAM_CTRL {
 	struct I {	/* -I[o] */
 		BOOLEAN active;
 		BOOLEAN dump;
+		BOOLEAN dumpall;
 	} I;
 	struct L {	/* -L<pen> */
 		BOOLEAN active;
@@ -164,20 +165,21 @@ int main (int argc, char **argv)
 				case 'G':
 					Ctrl->G.active = TRUE;
 					if (GMT_getfill (&argv[i][2], &Ctrl->G.fill)) {
-						GMT_fill_syntax ('G');
+						GMT_fill_syntax ('G', " ");
 						error++;
 					}
 					break;
 				case 'L':		/* Set line attributes */
 					Ctrl->L.active = TRUE;
 					if (GMT_getpen (&argv[i][2], &Ctrl->L.pen)) {
-						GMT_pen_syntax ('L');
+						GMT_pen_syntax ('L', " ");
 						error++;
 					}
 					break;
 				case 'I':
 					Ctrl->I.active = TRUE;
 					if (argv[i][2] == 'o') Ctrl->I.dump = TRUE;
+					if (argv[i][2] == 'O') Ctrl->I.dumpall = TRUE;
 					break;
 				case 'Q':
 					Ctrl->Q.active = TRUE;
@@ -227,7 +229,7 @@ int main (int argc, char **argv)
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr,"pshistogram %s - Calculate and plot histograms\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: pshistogram [file] %s -W<width> [%s] [-C] [-Eaz/el] [-G<fill>]\n", GMT_Jx_OPT, GMT_B_OPT);
-		fprintf (stderr, "\t[%s] [-I[o]] [-K] [-L<pen>] [-O] [-P] [-Q] [%s]\n", GMT_Ho_OPT, GMT_Rx_OPT);
+		fprintf (stderr, "\t[%s] [-I[o|O]] [-K] [-L<pen>] [-O] [-P] [-Q] [%s]\n", GMT_Ho_OPT, GMT_Rx_OPT);
 		fprintf (stderr, "\t[-S] [-T<col>] [%s] [-V] [%s] [%s]\n", GMT_U_OPT, GMT_X_OPT, GMT_Y_OPT);
 		fprintf (stderr, "\t[-Z[type]] [%s] [%s] [%s]\n\n", GMT_c_OPT, GMT_bi_OPT, GMT_f_OPT);
 
@@ -242,14 +244,13 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-A will plot horizontal bars [Default is vertical]\n");
 		fprintf (stderr, "\t-C will center the bins\n");
 		fprintf (stderr, "\t-E set azimuth and elevation of viewpoint for 3-D perspective [180/90]\n");
-		fprintf (stderr, "\t-G Specify color or pattern for columns. fill can be either\n");
-		fprintf (stderr, "\t   1) <r/g/b> (each 0-255) for color or <gray> (0-255) for gray-shade [0]\n");
-		fprintf (stderr, "\t   2) p[or P]<dpi>/<pattern> for predefined patterns (1-90).\n");
+		GMT_fill_syntax ('G', "Select color/pattern for columns.");
 		GMT_explain_option ('H');
 		fprintf (stderr, "\t-I will inquire about min/max x and y.  No plotting is done\n");
 		fprintf (stderr, "\t   Append o to output the resulting x, y data\n");
+		fprintf (stderr, "\t   Append O to output all resulting x, y data even with y=0\n");
 		GMT_explain_option ('K');
-		fprintf (stderr, "\t-L <pen> is penwidth. Specify r/g/b for colored line.\n");
+		GMT_pen_syntax ('L', "specify pen to draw histogram");
 		GMT_explain_option ('O');
 		GMT_explain_option ('P');
 		fprintf (stderr, "\t-Q plot a cumulative histogram\n");
@@ -419,12 +420,12 @@ int main (int argc, char **argv)
 	}
 
 	if (Ctrl->I.active) {	/* Only info requested, quit before plotting */
-		if (Ctrl->I.dump) {
+		if (Ctrl->I.dump||Ctrl->I.dumpall) {
 			int ibox;
 			double xx, yy;
 			sprintf (format, "%s\t%s\n", gmtdefs.d_format, gmtdefs.d_format);
 			for (ibox = 0; ibox < F.n_boxes; ibox++) {
-				if (F.boxh[ibox] == 0) continue;
+				if (Ctrl->I.dump&&(F.boxh[ibox] == 0)) continue;
 				xx = F.west + ibox * F.box_width;
 				if (F.center_box) xx -= (0.5 * F.box_width);
 				if (F.hist_type == PSHISTOGRAM_LOG_COUNTS)
