@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: psrose.c,v 1.43 2006/04/12 21:55:46 pwessel Exp $
+ *	$Id: psrose.c,v 1.44 2006/10/11 02:25:13 remko Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -164,7 +164,7 @@ int main (int argc, char **argv)
 				case 'G':		/* Set Gray shade */
 					Ctrl->G.active = TRUE;
 					if (GMT_getfill (&argv[i][2], &Ctrl->G.fill)) {
-						GMT_fill_syntax ('G');
+						GMT_fill_syntax ('G', " ");
 						error++;
 					}
 					break;
@@ -205,7 +205,7 @@ int main (int argc, char **argv)
 				case 'W':		/* Get pen width for outline */
 					Ctrl->W.active = TRUE;
 					if (GMT_getpen (&argv[i][2], &Ctrl->W.pen)) {
-						GMT_pen_syntax ('W');
+						GMT_pen_syntax ('W', " ");
 						error++;
 					}
 					break;
@@ -240,7 +240,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   (Remember: radial is x-direction, azimuthal is y-direction)\n");
 		fprintf (stderr, "\t-C plot vectors listed in the <modes> file.  If no file, use mean direction\n");
 		fprintf (stderr, "\t-E set azimuth and elevation of viewpoint for 3-D perspective [180/90]\n");
-		fprintf (stderr, "\t-G <fill> specify color for diagram.  [Default is no fill]\n");
+		GMT_fill_syntax ('G', "Specifies color for diagram [Default is no fill]");
 		GMT_explain_option ('H');
 		fprintf (stderr, "\t-I for inquire.  Only compute statistics - no plot is created\n");
 		GMT_explain_option ('K');
@@ -256,7 +256,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-T indicates that the vectors are oriented (two-headed), not directed [Default]\n");
 		GMT_explain_option ('U');
 		GMT_explain_option ('V');
-		fprintf (stderr, "\t-W sets pen attributes for outline of rose. [Default is no outline]\n");
+		GMT_pen_syntax ('W', "sets pen attributes for outline of rose. [Default is no outline].");
 		GMT_explain_option ('X');
 		fprintf (stderr, "\t-Z multiply the radii by scale before plotting\n");
 		GMT_explain_option ('c');
