@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: psscale.c,v 1.62 2006/04/12 21:55:46 pwessel Exp $
+ *	$Id: psscale.c,v 1.67 2006/11/01 19:11:23 remko Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -31,7 +31,8 @@
  *		3.3.4 21-JAN-2000. PW: Now paint rectangles for discrete cpt files
  *		      08-FEB-2000. PW: Also understand patterns for discrete cpt files
  *		      10-NOV-2003. PW: Enhanced -E to set back or foreground only
- *		      08-MAR-2006. PW: Enhanced -I to set lowe/high intensity
+ *		      08-MAR-2006. PW: Enhanced -I to set low/high intensity
+ *		      23-MAY-2006. PW: Added -Q to handle logarithmic scales
  * Version:	4
  *
  */
@@ -57,7 +58,7 @@ struct PSSCALE_CTRL {
 		int mode;
 		double length;
 	} E;
-	struct I {	/* -I[<intens> */
+	struct I {	/* -I[<intens>|<min_i>/<max_i>] */
 		BOOLEAN active;
 		double min, max;
 	} I;
@@ -73,6 +74,9 @@ struct PSSCALE_CTRL {
 		BOOLEAN interval;
 		double spacing;
 	} L;
+	struct Q {	/* -Q */
+		BOOLEAN active;
+	} Q;
 	struct S {	/* -S */
 		BOOLEAN active;
 	} S;
@@ -98,7 +102,7 @@ int main(int argc, char **argv)
 	struct PSSCALE_CTRL *Ctrl;
 
 	void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dpi, BOOLEAN flip_anot, BOOLEAN B_set, BOOLEAN equi, 
-	   BOOLEAN horizontal, BOOLEAN intens, double *max_intens, BOOLEAN skip_lines, int extend, double e_length, double gap, BOOLEAN interval_annot, BOOLEAN monochrome);
+	   BOOLEAN horizontal, BOOLEAN logscl, BOOLEAN intens, double *max_intens, BOOLEAN skip_lines, int extend, double e_length, double gap, BOOLEAN interval_annot, BOOLEAN monochrome);
 
 	void *New_Psscale_Ctrl (), Free_Psscale_Ctrl (struct PSSCALE_CTRL *C);
 	
@@ -195,6 +199,9 @@ int main(int argc, char **argv)
 					if (argv[i][2] == 'i') Ctrl->L.interval = TRUE, j = 3;
 					if (argv[i][j]) Ctrl->L.spacing = GMT_convert_units (&argv[i][j], GMT_INCH);
 					break;
+				case 'Q':
+					Ctrl->Q.active = TRUE;
+					break;
 				case 'S':
 					Ctrl->S.active = TRUE;
 					break;
@@ -215,8 +222,8 @@ int main(int argc, char **argv)
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "%s %s - To create grayscale or colorscale for maps\n\n", GMT_program, GMT_VERSION);
-		fprintf(stderr, "usage: psscale -D<xpos/ypos/length/width>[h] [-A] [-C<cpt_file>] [-E[b|f][<length>]] [%s] [-I[<intens>]\n", GMT_B_OPT);
-		fprintf(stderr, "\t[-K] [-L[i][<gap>]] [-M] [-N<dpi>] [-O] [-P] [-S] [%s] [-V] [%s]\n\t[%s] [-Z<zfile>] [%s]\n\n", GMT_U_OPT, GMT_X_OPT, GMT_Y_OPT, GMT_c_OPT);
+		fprintf(stderr, "usage: psscale -D<xpos/ypos/length/width>[h] [-A] [-C<cpt_file>] [-E[b|f][<length>]] [%s] [-I[<max_intens>|<low_i>/<high_i>]\n", GMT_B_OPT);
+		fprintf(stderr, "\t[-K] [-L[i][<gap>]] [-M] [-N<dpi>] [-O] [-P] [-Q] [-S] [%s] [-V] [%s]\n\t[%s] [-Z<zfile>] [%s]\n\n", GMT_U_OPT, GMT_X_OPT, GMT_Y_OPT, GMT_c_OPT);
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
 
 		fprintf (stderr, "\t-D set mid-point position and length/width for scale.\n");
@@ -233,17 +240,19 @@ int main(int argc, char **argv)
 		fprintf (stderr, "\t-E add sidebar triangles for back- and foreground colors.\n");
 		fprintf (stderr, "\t   Specify b(ackground) or f(oreground) to get one only [Default is both]\n");
 		fprintf (stderr, "\t   Optionally, append triangle height [Default scales with barwidth]\n");
-		fprintf (stderr, "\t-I add illumination for +- <intens> [1.0]\n");
+		fprintf (stderr, "\t-I add illumination for +-<max_intens> or <low_i> to <high_i> [-1.0/1.0]\n");
 		fprintf (stderr, "\t   Alternatively, specify <lower>/<upper> intensity values\n");
 		GMT_explain_option ('K');
 		fprintf (stderr, "\t-L For equal-sized color rectangles. -B interval, if set, is ignored\n");
 		fprintf (stderr, "\t   Append i to annotate the interval range instead of lower/upper.\n");
 		fprintf (stderr, "\t   If <gap> is appended, we separate each rectangle by <gap> units and center each\n");
 		fprintf (stderr, "\t   lower (z0) annotation on the rectangle.  Ignored if not a discrete cpt table.\n");
+		fprintf (stderr, "\t   If -I is used then each rectangle will have the illuminated constant color.\n");
 		fprintf (stderr, "\t-M force monochrome colorbar using GMT_YIQ transformation\n");
 		fprintf (stderr, "\t-N effective dots-per-inch for color scale [300]\n");
 		GMT_explain_option ('O');
 		GMT_explain_option ('P');
+		fprintf (stderr, "\t-Q Plot colorbar using logarithmic scale and annotate powers of 10 [Default is linear]\n");
 		fprintf (stderr, "\t-S Skip drawing color boundary lines on color scale [Default draws lines]\n");
 		GMT_explain_option ('U');
 		GMT_explain_option ('V');
@@ -292,6 +301,18 @@ int main(int argc, char **argv)
 	if (gmtdefs.verbose) fprintf (stderr, "  CPT range from %g to %g\n",
 		GMT_lut[0].z_low, GMT_lut[GMT_n_colors-1].z_high);
 
+	if (Ctrl->Q.active) {	/* Take log of all z values */
+		for (i = 0; i < GMT_n_colors; i++) {
+			if (GMT_lut[i].z_low <= 0.0 || GMT_lut[i].z_high <= 0.0) {
+				fprintf (stderr, "%s: GMT SYNTAX ERROR -Q option: All z-values must be positive for logarithmic scale\n", GMT_program);
+				exit (EXIT_FAILURE);
+			}
+			GMT_lut[i].z_low = d_log10 (GMT_lut[i].z_low);
+			GMT_lut[i].z_high = d_log10 (GMT_lut[i].z_high);
+			GMT_lut[i].i_dz = 1.0 / (GMT_lut[i].z_high - GMT_lut[i].z_low);
+		}
+	}
+	
 	if (Ctrl->E.mode && Ctrl->E.length == 0.0) Ctrl->E.length = Ctrl->D.width * 0.5;
 	max_intens[0] = Ctrl->I.min;
 	max_intens[1] = Ctrl->I.max;
@@ -380,7 +401,7 @@ int main(int argc, char **argv)
 		ps_transrotate (GMT_ps.x_origin, GMT_ps.y_origin, 0.0);
 	}
 
-	GMT_draw_colorbar (Ctrl->D.length, Ctrl->D.width, z_width, Ctrl->N.dpi, Ctrl->A.active, B_set, Ctrl->L.active, Ctrl->D.horizontal, Ctrl->I.active, max_intens, Ctrl->S.active, Ctrl->E.mode, Ctrl->E.length, Ctrl->L.spacing, Ctrl->L.interval, Ctrl->M.active);
+	GMT_draw_colorbar (Ctrl->D.length, Ctrl->D.width, z_width, Ctrl->N.dpi, Ctrl->A.active, B_set, Ctrl->L.active, Ctrl->D.horizontal, Ctrl->Q.active, Ctrl->I.active, max_intens, Ctrl->S.active, Ctrl->E.mode, Ctrl->E.length, Ctrl->L.spacing, Ctrl->L.interval, Ctrl->M.active);
 
 	if (must_shift_back) ps_transrotate (-x_origin, -y_origin, 0.0);
 
@@ -397,13 +418,13 @@ int main(int argc, char **argv)
 	exit (EXIT_SUCCESS);
 }
 
-void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dpi, BOOLEAN flip_anot, BOOLEAN B_set, BOOLEAN equi, BOOLEAN horizontal, BOOLEAN intens, double *max_intens, BOOLEAN skip_lines, int extend, double e_length, double gap, BOOLEAN interval_annot, BOOLEAN monochrome)
+void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dpi, BOOLEAN flip_anot, BOOLEAN B_set, BOOLEAN equi, BOOLEAN horizontal, BOOLEAN logscl, BOOLEAN intens, double *max_intens, BOOLEAN skip_lines, int extend, double e_length, double gap, BOOLEAN interval_annot, BOOLEAN monochrome)
 {
-	int i, ii, id, j, ndec = -1, dec, depth, rgb[3], rrggbb[3];
-	int nx = 0, ny = 0, nm, barmem, k, justify, l_justify, this_just, use_labels = 0;
-	BOOLEAN reverse, all = TRUE, use_image, center = FALSE, const_width = TRUE;
+	int i, ii, id, j, ndec = -1, dec, p_val, depth, rgb[3], rrggbb[3];
+	int nx = 0, ny = 0, nm, barmem, k, justify, l_justify, this_just, use_labels = 0, Label_justify;
+	BOOLEAN reverse, all = TRUE, use_image, center = FALSE, const_width = TRUE, do_annot;
 	char format[GMT_LONG_TEXT], text[GMT_LONG_TEXT], test[GMT_LONG_TEXT], unit[GMT_LONG_TEXT];
-	unsigned char *bar = 0;
+	unsigned char *bar = 0, *tmp = 0;
 	double off, annot_off, label_off, len, len2, size, x0, x1, dx, xx, dir, y_base;
 	double z, xleft, xright, inc_i, inc_j;
 	double get_z (double x, double *width, int n);
@@ -472,7 +493,7 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 	}
 	if (gap < 0.0) gap = 0.0;
 
-	if (use_image) {	/* Make bitimage for colorbar using bit_dpi */
+	if (use_image || intens) {	/* Make bitimage for colorbar using bit_dpi */
 		nx = (GMT_continuous) ? irint (length * bit_dpi) : GMT_n_colors;
 		ny = (intens) ? irint (width * bit_dpi) : 1;
 		nm = nx * ny;
@@ -484,7 +505,7 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 		/* Load bar image */
 
 		for (i = 0; i < nx; i++) {
-			z = get_z ((i+0.5) * inc_i, z_width, GMT_n_colors);
+			z = (GMT_continuous) ? get_z ((i+0.5) * inc_i, z_width, GMT_n_colors) : GMT_lut[i].z_low;
 			GMT_get_rgb24 (z, rrggbb);
 			ii = (reverse) ? nx - i - 1 : i;
 			for (j = 0; j < ny; j++) {
@@ -514,11 +535,13 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 	if (flip_anot) {
 		justify = (horizontal) ? 2 : 5;
 		l_justify = (horizontal) ? 2 : 7;
+		Label_justify = 2;
 		y_base = width;
 		dir = -1.0;
 	}
 	else {
 		justify = (horizontal) ? 10 : 7;
+		Label_justify = 10;
 		l_justify = (horizontal) ? 10 : 5;
 		y_base = 0.0;
 		dir = 1.0;
@@ -541,8 +564,20 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 					xp[0] = xp[3] = x0 + gap;	xp[1] = xp[2] = x1 - gap;
 					ps_imagefill (xp, yp, 4, f->pattern_no, f->pattern, f->inverse, f->dpi, center, f->f_rgb, f->b_rgb);	/* Contours drawn separately below if desired */
 				}
+				else if (intens) {
+					ii = (GMT_gray || monochrome) ? 1 : 3;
+					tmp = (unsigned char *) GMT_memory (VNULL, (size_t)ny*ii, sizeof (char), GMT_program);
+					for (j = 0, k = i*ii; j < ny*ii; k+=(nx-1)*ii) {
+						tmp[j++] = bar[k++];
+						tmp[j++] = bar[k++];
+						tmp[j++] = bar[k++];
+					}
+					GMT_color_image (x0 + gap, 0.0, z_width[i] - 2*gap, width, tmp, 1, ny, depth);
+					GMT_free ((void *)tmp);
+				}
 				else {
 					memcpy ((void *)rgb, (void *)GMT_lut[ii].rgb_low, (size_t)(3 * sizeof (int)));
+					if (intens) GMT_illuminate (max_intens[1], rgb);
 					if (monochrome) rgb[0] = rgb[1] = rgb[2] = GMT_YIQ (rgb);
 					ps_rect (x0+gap, 0.0, x1-gap, width, rgb, center);
 				}
@@ -620,15 +655,23 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 				if (all || (GMT_lut[i].annot & 1)) {	/* Annotate this */
 					if (!center) ps_plotr (0.0, -(len * dir), PSL_PEN_DRAW_AND_STROKE);
 					this_just = justify;
+					do_annot = TRUE;
 					if (use_labels && GMT_lut[i].label) {
 						strcpy (text, GMT_lut[i].label);
 						this_just = l_justify;
 					}
 					else if (center && interval_annot)
 						sprintf (text, format, GMT_lut[i].z_low, GMT_lut[i].z_high);
+					else if (logscl) {
+						p_val = irint (GMT_lut[i].z_low);
+						if (fabs (GMT_lut[i].z_low - (double)p_val) > GMT_CONV_LIMIT)
+							do_annot = FALSE;
+						else
+							sprintf (text, "10@+%d@+", irint (GMT_lut[i].z_low));
+					}
 					else
 						sprintf (text, format, GMT_lut[i].z_low);
-					ps_text (xx, y_base - (dir * annot_off), gmtdefs.annot_font_size[0], text, 0.0, -this_just, 0);
+					if (do_annot) ps_text (xx, y_base - (dir * annot_off), gmtdefs.annot_font_size[0], text, 0.0, -this_just, 0);
 				}
 				else
 					if (!center) ps_plotr (0.0, -(len2 * dir), PSL_PEN_DRAW_AND_STROKE);
@@ -641,15 +684,24 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 				if (all || (GMT_lut[i].annot & 2)) {
 					ps_plotr (0.0, -(len * dir), PSL_PEN_DRAW_AND_STROKE);
 					this_just = justify;
-					sprintf (text, format, GMT_lut[i].z_high);
-					ps_text (xx, y_base - (dir * annot_off), gmtdefs.annot_font_size[0], text, 0.0, -this_just, 0);
+					do_annot = TRUE;
+					if (logscl) {
+						p_val = irint (GMT_lut[i].z_high);
+						if (fabs (GMT_lut[i].z_high - (double)p_val) > GMT_CONV_LIMIT)
+							do_annot = FALSE;
+						else
+							sprintf (text, "10@+%d@+", p_val);
+					}
+					else
+						sprintf (text, format, GMT_lut[i].z_high);
+					if (do_annot) ps_text (xx, y_base - (dir * annot_off), gmtdefs.annot_font_size[0], text, 0.0, -this_just, 0);
 				}
 				else
 					ps_plotr (0.0, -(len2 * dir), PSL_PEN_DRAW_AND_STROKE);
 			}
 			if (frame_info.axis[0].label[0]) {
 				ps_setfont (gmtdefs.label_font);
-				ps_text (xleft+0.5*length, y_base + (dir * label_off), gmtdefs.label_font_size, frame_info.axis[0].label, 0.0, justify, 0);
+				ps_text (xleft+0.5*length, y_base + (dir * label_off), gmtdefs.label_font_size, frame_info.axis[0].label, 0.0, Label_justify, 0);
 			}
 		}
 		if (unit[0]) {	/* Add unit label */
@@ -671,8 +723,20 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 					xp[0] = xp[3] = x0 + gap;	xp[1] = xp[2] = x1 - gap;
 					ps_imagefill (xp, yp, 4, f->pattern_no, f->pattern, f->inverse, f->dpi, center, f->f_rgb, f->b_rgb);	/* Contours drawn separately below if desired */
 				}
+				else if (intens) {
+					ii = (GMT_gray || monochrome) ? 1 : 3;
+					tmp = (unsigned char *) GMT_memory (VNULL, (size_t)ny*ii, sizeof (char), GMT_program);
+					for (j = 0, k = i*ii; j < ny*ii; k+=(nx-1)*ii) {
+						tmp[j++] = bar[k++];
+						tmp[j++] = bar[k++];
+						tmp[j++] = bar[k++];
+					}
+					GMT_color_image (x0 + gap, 0.0, z_width[i] - 2*gap, width, tmp, 1, ny, depth);
+					GMT_free ((void *)tmp);
+				}
 				else {
 					memcpy ((void *)rgb, (void *)GMT_lut[i].rgb_low, (size_t)(3 * sizeof (int)));
+					if (intens) GMT_illuminate (max_intens[1], rgb);
 					if (monochrome) rgb[0] = rgb[1] = rgb[2] = GMT_YIQ (rgb);
 					ps_rect (x0 + gap, 0.0, x1 - gap, width, rgb, center);
 				}
@@ -695,6 +759,7 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 		}
 		if (use_labels) off = 0.0;
 		annot_off = -(((len > 0.0 && !center) ? len : 0.0) + gmtdefs.annot_offset[0] + off);
+		if (logscl) annot_off = -(((len > 0.0 && !center) ? len : 0.0) + gmtdefs.annot_offset[0]);
 		label_off = annot_off - 0.7 * gmtdefs.annot_font_size[0] * GMT_u2u[GMT_PT][GMT_INCH] - 1.5 * gmtdefs.annot_offset[0];
 		if (extend & 1) {	/* Add color triangles for background */
 			xp[0] = xp[1] = xleft - gap;	xp[2] = xp[0] - e_length;
@@ -767,15 +832,24 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 				if (all || (GMT_lut[i].annot & 1)) {
 					if (!center) ps_plotr (0.0, -(len * dir), PSL_PEN_DRAW_AND_STROKE);
 					this_just = justify;
+					do_annot = TRUE;
 					if (use_labels && GMT_lut[i].label) {
 						strcpy (text, GMT_lut[i].label);
 						this_just = l_justify;
 					}
 					else if (center && interval_annot)
 						sprintf (text, format, GMT_lut[i].z_low, GMT_lut[i].z_high);
+					else if (logscl) {
+						p_val = irint (GMT_lut[i].z_low);
+						if (fabs (GMT_lut[i].z_low - (double)p_val) > GMT_CONV_LIMIT)
+							do_annot = FALSE;
+						else
+							sprintf (text, "10@+%d@+", p_val);
+						this_just = l_justify;
+					}
 					else
 						sprintf (text, format, GMT_lut[i].z_low);
-					ps_text (xx, y_base + (dir * annot_off), gmtdefs.annot_font_size[0], text, -90.0, -this_just, 0);
+					if (do_annot) ps_text (xx, y_base + (dir * annot_off), gmtdefs.annot_font_size[0], text, -90.0, -this_just, 0);
 				}
 				else
 					if (!center) ps_plotr (0.0, -(dir * len2), PSL_PEN_DRAW_AND_STROKE);
@@ -788,8 +862,18 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 				if (all || (GMT_lut[i].annot & 2)) {
 					ps_plotr (0.0, -(len * dir), PSL_PEN_DRAW_AND_STROKE);
 					this_just = justify;
-					sprintf (text, format, GMT_lut[i].z_high);
-					ps_text (xx, y_base + (dir * annot_off), gmtdefs.annot_font_size[0], text, -90.0, -this_just, 0);
+					do_annot = TRUE;
+					if (logscl) {
+						p_val = irint (GMT_lut[i].z_high);
+						if (fabs (GMT_lut[i].z_high - (double)p_val) > GMT_CONV_LIMIT)
+							do_annot = FALSE;
+						else
+							sprintf (text, "10@+%d@+", p_val);
+						this_just = l_justify;
+					}
+					else
+						sprintf (text, format, GMT_lut[i].z_high);
+					if (do_annot) ps_text (xx, y_base + (dir * annot_off), gmtdefs.annot_font_size[0], text, -90.0, -this_just, 0);
 				}
 				else
 					ps_plotr (0.0, -(len2 * dir), PSL_PEN_DRAW_AND_STROKE);
@@ -799,7 +883,7 @@ void GMT_draw_colorbar (double length, double width, double *z_width, int bit_dp
 		if (frame_info.axis[0].label[0]) {
 			ps_setfont (gmtdefs.label_font);
 			if (strchr (frame_info.axis[0].label, '@') || strchr (frame_info.axis[0].label, '(')) {	/* Must set text horizontally */
-				ps_text (xleft+0.5*length, y_base + (dir * label_off), gmtdefs.label_font_size, frame_info.axis[0].label, 0.0, justify, 0);
+				ps_text (xleft+0.5*length, y_base + (dir * label_off), gmtdefs.label_font_size, frame_info.axis[0].label, 0.0, Label_justify, 0);
 			}
 			else {
 				size = 0.9 * gmtdefs.label_font_size * GMT_u2u[GMT_PT][GMT_INCH];
